// render first "prox_illusion.pov" with +fn16 (w/h - 16:9) and copy image in this folder

// render this file with +kfi1 +kff25

#version 3.7;

#declare PHOT      = 0;  // photons 0=out; 1=save photons; 2=load photons
#declare RAD       = 8;  // radiosity quality settings 0=out; 1=acceptable; 5=good
                
global_settings {
        #declare a_g = 2.2;
        assumed_gamma a_g
        max_trace_level 5
        subsurface {radiosity on samples 200, 200}
        noise_generator 2
        #if (PHOT > 0)
                photons {                                 
                        spacing 0.05
                        autostop 0
                        jitter 1
                        #if (PHOT = 1)
                                save_file "pov.ph"
                        #else
                                load_file "pov.ph"
                        #end                        
                }                                                               
        #end  
        #if(RAD > 0)
                radiosity {
                        pretrace_start 0.08
                        pretrace_end   0.04/RAD
                        count 60*RAD                
                        nearest_count min (20, RAD)      
                        error_bound 2/RAD
                        low_error_factor 0.5      
                        recursion_limit 1      
                        gray_threshold 0  
                        minimum_reuse 0.015 
                        brightness 1      
                        adc_bailout 0.005
                        normal on
                        media off
                        always_sample off
                }
        #end
}        

#include "stdinc.inc"
#include "stones.inc" 

#declare camloc = <50,0,-201.5>;
#declare lookat = <0,0,0>;
#declare camang = 46;

camera {
        location camloc   
        right x*image_width/image_height 
        look_at lookat
        angle camang
}

#include "CGSphere4.inc" 

object {Ground scale <1.9,1,1>} 

#declare mat = frame_number;
 
//________________________________________________________________________________________________________________________________________________________________  

#macro Ga (Color)

<pow (Color.x,1/a_g),pow (Color.y,1/a_g),pow (Color.z,1/a_g)>

#end

#macro Gat (Color)

<pow (Color.x,1/a_g),pow (Color.y,1/a_g),pow (Color.z,1/a_g),Color.t>

#end

#macro vpow (V, P)

<pow (V.x,P),pow (V.y,P),pow (V.z,P)>

#end     

//________________________________________________________________________________________________________________________________________________________________

// illusion 

#declare illusion_image     = "prox_illusion.png"
#declare illusion_location  = camloc;
#declare illusion_look_at   = lookat;
#declare illusion_angle     = camang;

#ifndef (illusion_location)  #declare illusion_location  = <0,0,0>; #end
#ifndef (illusion_right)     #declare illusion_right     = image_width/image_height*x;  #end
#ifndef (illusion_up)        #declare illusion_up        = y;       #end
#ifndef (illusion_direction) #declare illusion_direction = z;       #end
#ifndef (illusion_sky)       #declare illusion_sky       = y;       #end
#ifndef (illusion_angle)     #declare illusion_angle     = degrees (atan2 (vlength (illusion_right)/2/vlength (illusion_direction), 1))*2; #end
#ifndef (illusion_look_at)   #declare illusion_look_at   = illusion_location+illusion_direction; #end

#ifndef (illusion_image)     #debug "\n\n--> you must specify 'illusion_image'!\n\n"  #end

#declare illusion_format = strlwr (substr (illusion_image,strlen (illusion_image)-3, 4))
#if (strcmp (illusion_format,".png") != 0 & strcmp (illusion_format,".tga") != 0)
        #debug concat (
                "\n\n--> extension of illusion_image: ",
                strlwr (substr (illusion_image, strlen (illusion_image)-3,4)),
                "\n--> illusion_image must be a .png or .tga file!\n\n"
        )
#end
   
// CREATE THE IMAGE MAP USED IN THE ILLUSION
// *****************************************
#ifdef (illusion_image_function)
        #undef illusion_image_function
#end
#declare illusion_image_function =
function {
        #if (strcmp (illusion_format,".png") = 0)
                pigment {image_map {png illusion_image gamma 2.2 once} translate -0.5}
        #else
                pigment {image_map {tga illusion_image gamma 2.2 once} translate -0.5}
        #end
}
   
// CREATE THE RAW ILLUSION ALIGNED ALONG Z AXIS
// ********************************************
#declare illusion_raw =
pigment {
        average
        pigment_map {
                [1      function {illusion_image_function (x/z,y/z,z).red}      color_map {[0  rgb 0][1  rgb <4,0,0>]}]
                [1      function {illusion_image_function (x/z,y/z,z).green}    color_map {[0  rgb 0][1  rgb <0,4,0>]}]
                [1      function {illusion_image_function (x/z,y/z,z).blue}     color_map {[0  rgb 0][1  rgb <0,0,4>]}]
                [1      function {illusion_image_function (x/z,y/z,z).transmit} color_map {[0  rgb 0][1  transmit 4]}]
        }                                                                       
}
   
// ALIGNMENT CALCULATIONS
// **********************
#declare illusion_t = illusion_location;
#declare illusion_z = vnormalize (illusion_look_at-illusion_location);
#declare illusion_x = vnormalize (vcross (illusion_sky, illusion_z))*tan (radians (illusion_angle/2))*2;
#declare illusion_y = vnormalize (vcross (illusion_z, illusion_x))*tan (radians (illusion_angle/2))*2*vlength (illusion_up)/vlength (illusion_right); 

/////////////////////////////////////////////////////////////////////////////////////

#if (mat = 1) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// partly polished copper?

#declare copper1 =
texture {
	pigment {color srgb <228,133,95>/255}
	finish {
		ambient 0
		diffuse 0.1
		brilliance 3
		specular 0.7
		roughness 0.01
		phong 0.7
		phong_size 75
		metallic
		reflection {0.7 metallic}
	}
	normal {
                average
                normal_map {
                        [1      wrinkles 0.1 scale 0.02]
                        [1      wrinkles 0.1 scale 0.063]
                        [1      wrinkles 0.1 scale 0.2]
                }
        }
}

#declare copper2 =
texture {
	pigment {color srgb (<228,133,95>+<98,76,78>)/510}
	finish {
		ambient 0
		diffuse 0.35
		brilliance 2
		specular 0.3
		roughness 0.05
		metallic
		reflection {0.1 metallic}
	}
	normal {
                average
                normal_map {
                        [1      wrinkles 0.25 scale 0.02]
                        [1      wrinkles 0.25 scale 0.063]
                        [1      wrinkles 0.25 scale 0.2]
                }
        }
}

#declare copper3 =
texture {
	pigment {color srgb <98,76,78>/255}
	finish {
		ambient 0
		diffuse 0.6
		brilliance 1
		specular 0.1
		roughness 0.2
		metallic 
		reflection {0 metallic}
	}
	normal {
                average
                normal_map {
                        [1      wrinkles scale 0.02]
                        [1      wrinkles scale 0.063]
                        [1      wrinkles scale 0.2]
                }
        }
}
texture {      
	pigment {
		wrinkles
		scallop_wave
		turbulence 0.31
		omega 0.65
		lambda 3
		color_map {
			[0      rgbt 1]
			[0.2    rgbt 1]
			[0.2    rgbt Gat (<0.1,0.015,0.005,1>)]
			[0.53   rgbt Gat (<0.1,0.015,0.005,0.14>)]
			[0.7    rgbt Gat (<0.15,0.035,0.009,0.4>)]
			[0.89   rgbt Gat (<0.15,0.035,0.009,1>)]
			[1      rgbt 1]
		}
		scale 0.25
	}
	finish {ambient 0 diffuse 0.7}
	normal {wrinkles 1}

}
texture {       
	pigment {
		wrinkles
		turbulence 0.51
		omega 0.675
		lambda 2.5
		color_map {
			[0      rgbt 1]
			[0.3    rgbt 1]
			[0.3    rgbt Gat (<0.1,0.015,0.005,1>)]
			[0.53   rgbt Gat (<0.1,0.015,0.005,0.24>)]
			[0.675  rgbt Gat (<0.15,0.025,0.009,0.55>)]
			[0.79   rgbt Gat (<0.15,0.025,0.009,1>)]
			[1      rgbt 1]
		}
	}
	finish {ambient 0 diffuse 0.7}
	normal {wrinkles 1}

}
texture {
	pigment {
		bozo
		turbulence 0.675
		omega 0.85
		lambda 3
		color_map {
			[0      rgbt Gat (<0.06,0.02,0.004,0.9>)]
			[1      rgbt Gat (<0.06,0.02,0.004,0.1>)]
		}
		scale <0.7,1.2,0.5>
	}
	finish {ambient 0 diffuse 0.4}
	normal {
		average
		normal_map {
			[1      dents 1 scale 0.07 turbulence 0.2 omega 0.6 lambda 2.5]
			[0.5    granite 0.5 scale 0.1 turbulence 0.4 omega 0.65 lambda 2.5]
			[0.75   wrinkles 0.1 scale 2 turbulence 0.2 omega 0.6 lambda 2.5]
		}
	}
}
texture {
	pigment {
		bozo
		turbulence 0.475
		omega 0.85
		lambda 3
		color_map {
			[0      srgbt Gat (<0.04,0.015,0.01,0.8>)]
			[1      srgbt Gat (<0.04,0.015,0.01,0.05>)]
		}
		scale <1,3.75,1>
	}
	finish {ambient 0 diffuse 0.3}
	normal {
		average
		normal_map {
			[1      dents 1 scale 0.07 turbulence 0.2 omega 0.6 lambda 2.5]
			[0.5    granite 0.5 scale 0.1 turbulence 0.4 omega 0.65 lambda 2.5]
			[0.75   wrinkles 0.1 scale 2 turbulence 0.2 omega 0.6 lambda 2.5]
		}
	}
}

#declare fn_Displace =
function {
	pattern {
		bozo
		poly_wave 1.4
		warp {
			turbulence <0.4,0.4,0.4>
			omega 0.55
			octaves 7
		}
		translate -12
	}
}

#declare copper4 =
texture {
	pigment {color srgb <156,236,197>/255}
	finish {
		diffuse 0.3
		ambient 0
		reflection {0, 0.2 metallic}
		specular 0.05
		roughness 0.2
                metallic
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 1 scale 0.001]
			[1      function {fn_Displace (x,y,z)} scale 0.05 bump_size -0.5]
		}
	}
} 

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.66  copper4 scale 4]
                	[0.68  copper3 scale 4]
                	[0.72  copper3 scale 4]
                	[0.73  copper2 scale 4]
                        [0.74  copper1 scale 4]
                }
        }
	interior {ior 1.6}
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.55  copper4 scale 4]
                	[0.6   copper3 scale 4]
                	[0.72  copper3 scale 4]
                	[0.74  copper2 scale 4]
                        [0.76  copper1 scale 4]
                }
        }
	interior {ior 2.6}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 2) #declare light_ = 0.4; /////////////////////////////////////////////////////////////////////////////////////

// camp

#declare ash_Tex =
texture {
	pigment {
		leopard
		translate 52
		warp {turbulence 1 lambda 3}
		translate -48
		color_map {
			[0      rgb 0.3]
			[0.15   rgb 0.4]
			[0.4    rgb 0.3]
			[0.85   rgb 0.35]
			[1      rgb 0.4]
		}
	}
	normal {
		leopard 2
		translate 52
		warp {turbulence 1 lambda 3}
		translate -48
	}
	finish {emission 0.16667*0.5 diffuse 0.33333 irid {1 thickness 0.25}}
	scale 0.3
}
texture {
	pigment {
		crackle
		scale 0.75
		translate 53
		warp {turbulence 0.5 lambda 3}
		translate -47
		color_map {
			[0      rgb 0.3]
			[0.1    rgb 0.35]
			[0.5    rgb 0.4]
			[0.7    Clear]
			[1      Clear]
		}
	}
	normal {
		crackle 1
		scale 0.75
		translate 53
		warp {turbulence 0.5 lambda 3}
		translate -47
	}
	finish {emission 0.16667*0.5 diffuse 0.16667*2}
	scale 0.3
}

#declare glow_Tex =
texture {
	pigment {color rgb <0.4,0.05,0.01>}
	finish {
		specular 0.5
		metallic
		roughness 0.2
		emission 1.1
	}
	normal {granite 0.2 scale 0.00041}
}
texture {
	pigment {
		wrinkles
		scale 0.6
		ramp_wave
		color_map {
			[0      Red*0.95+Yellow*0.4+0.05]
			[0.3    Red*0.9 transmit 0.85]
			[0.5    Clear]
		}
	}
	finish {emission 0.75 diffuse 0.25}
}
texture {
	pigment {
		crackle
		scale 0.75
		scale 5
		translate 55
		warp {turbulence 1 lambda 3}
		translate -45
		scale 0.2
		color_map {
			[0      Clear]
			[0.1    Red*0.9 transmit 0.85]
			[1      Red*0.95+Yellow*0.4]
		}
		scale 0.2
	}
	normal {
		crackle 1
		scale 0.75
		scale 5
		translate 55
		warp {turbulence 1 lambda 3}
		translate -45
		scale 0.04
	}
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.5   glow_Tex scale 2]
                        [0.8   ash_Tex scale 2]
                }
        }
	interior {ior 2.5}
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.5   glow_Tex scale 2]
                        [0.8   ash_Tex scale 2]
                }
        }
	interior {ior 2.5}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 3) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// based on Tim McMurdo  Capstan fnished...I promise  http://news.povray.org/povray.binaries.images/thread/%3Cweb.42efc7029ecf5192acb32c570%40news.povray.org%3E/

#declare RGB_ = rgb <93,38,41>/255;
#declare Scale_ = 0.7;

#declare P_WoodGrain7A_ =
pigment {
	wood
	turbulence <0.05,0.08,1000>
	octaves 4
	scale <0.15,0.15,1>
}

#declare P_WoodGrain7B_ =
pigment {
	bozo
	scale <0.01,0.01,100000>
}

#declare M_Wood7A_ =
color_map {
	[0, 0.1   color rgb <0.6,0.35,0.2>      color rgb <0.6,0.35,0.2>]
	[0.1, 0.9 color rgb <0.6,0.35,0.2>      color rgb <0.9,0.65,0.3>]
	[0.9, 1   color rgb <0.9,0.65,0.3>      color rgb <0.6,0.35,0.2>]
}
#declare M_Wood7B_ =
color_map {
	[0, 0.1   color rgb <0.9,0.65,0.3>      color rgbt <0.9,0.65,0.3,0.3>]
	[0.1, 1   color rgbt <0.9,0.65,0.3,0.3> color rgbt 1]
}

#declare T_Wood7_ =
texture {
	pigment {P_WoodGrain7A_ color_map {M_Wood7A_}}
	normal {
		pigment_pattern {P_WoodGrain7A_ color_map {M_Wood7A_}}
		-1
	}
}
texture {
	pigment {P_WoodGrain7B_ color_map {M_Wood7B_}}
	normal {
		pigment_pattern {P_WoodGrain7B_ color_map {M_Wood7B_}}
		0.1
	}
}

#declare TWood1 =
texture {T_Wood7_}
texture {
        pigment {color rgbt <255,155,23,0.999999*255>/255*0.25}
}

#declare TWood2 =
texture {T_Wood7_}
texture {
        pigment {color rgbt <255,155,23,1.5*255>/255*0.45}
}

#declare Wood =
texture {
	bozo
	texture_map {
		[0      TWood1]
		[1      TWood2]
	}
	warp {turbulence 0.2}
	scale <0.25,0.25,50>*Scale_
	rotate <-45,45,0>
}

#declare Texture1 =
texture {
	pigment_pattern {
		P_WoodGrain7A_
		color_map {
			[0, 0.1   color rgb <0.6,0.35,0.2>  color rgb <0.6,0.35,0.2>]
			[0.1, 1   color rgb <0.6,0.35,0.2>  color rgb <0.9,0.65,0.3>]
		}
		warp {turbulence 0.2}
		scale <0.25,0.25,50>*Scale_
		rotate <-45,45,0>
	}
	texture_map {
		[0.6    pigment {
				pigment_pattern {
					P_WoodGrain7A_
					color_map {M_Wood7A_}
					warp {turbulence 0.2}
					scale <0.25,0.25,50>*Scale_
					rotate <-45,45,0>
				}
				color_map {
					[0      RGB_]
					[0.1    RGB_]
					[0.1    0.8*RGB_]
					[0.9    0.8*RGB_]
					[1      RGB_]
				}
			}
			finish {
				ambient 0
				phong 0.05
				phong_size 250
			}
			normal {
				pigment_pattern {
					P_WoodGrain7A_
					color_map {M_Wood7A_}
					warp {turbulence 0.2}
					scale <0.25,0.25,50>*Scale_
					rotate <-45,45,0>
				}
				0.2
			}
		]
		[0.68   Wood]
	}
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.73   Texture1 scale 10]
                        [0.83   Wood scale 10]
                }
        }
	interior {ior 2.5}
	scale 1
} 

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.73   Texture1 scale 10]
                        [0.83   Wood scale 10]
                }
        }
	interior {ior 2.5}
	scale 1
} 

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 4) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Sean Day  decoy  http://news.povray.org/povray.binaries.scene-files/attachment/%3Cweb.53da248f183fb6647dded57b0%40news.povray.org%3E/decoy.zip

#declare brownCeramic =
texture {
	pigment {
		granite
		omega 0.8
		turbulence 0.4
		scale <0.02,0.1,0.02>
		color_map {
			[0      rgb Ga (<0.04,0.013,0.001>)]
			[0.45   rgb Ga (<0.02,0.01,0.0002>)]
			[0.9    rgb Ga (<0.2,0.085,0.01>*1.5)]
		}
	}
	finish {
		specular albedo 0.3
		roughness 0.02
		brilliance 4.2
		diffuse albedo 0.35*3
		reflection {0.01, 0.2 fresnel on}
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 0.1
				omega 0.7
				scale <0.02,0.1,0.02>
			]
			[1      dents 1
				scale <0.02,0.1,0.02>
			]
		}
	}
}

#declare lightCeramic =
texture {
	pigment {
		granite
		omega 0.8
		turbulence 0.4
		scale <0.02,0.1,0.02>
		color_map {
			[0      rgb Ga (<0.3,0.165,0.05>*1.5)]
			[0.45   rgb Ga (<0.2,0.085,0.01>*1.5)]
			[0.8    rgb Ga (<0.04,0.015,0.001>)]
		}
	}
	finish {
		specular albedo 0.3
		roughness 0.02
		brilliance 2.2
		diffuse albedo 0.45*3
		reflection {0.01, 0.2 fresnel on}
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 0.1
				omega 0.7
				scale <0.02,0.1,0.02>
			]
			[1      dents 1
				scale <0.02,0.1,0.02>
			]
		}
	}
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                        [0.76   brownCeramic scale 20]
                        [0.82   lightCeramic scale 20]
                }
        }
	interior {ior 1.5}
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                        [0.74   brownCeramic scale 20]
                        [0.92   lightCeramic scale 20]
                }
        }
	interior {ior 1.5}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 5) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Mike Sobers  [How to make] Stone texture  http://news.povray.org/povray.binaries.scene-files/attachment/%3Cweb.448053c14d93b2301009749b0%40news.povray.org%3E/stonetex3.pov.txt

#declare base =
texture {
	pigment {
		granite
		color_map {
			[0.3    rgb <0.2,0.2,0.25>]
			[0.8    rgb <0.15,0.15,0.2>]
			[1      rgb <0.3,0.3,0.35>]
		}
		frequency 6
		rotate <0,10,0>
		turbulence <0.05,0.05,0.05>
		octaves 6
		omega 0.7
		lambda 2
	}
	finish {
		ambient 0
		diffuse 0.3*3
		roughness 1
	}
	scale 2
}

#declare base2 =
texture {
	pigment {
		granite
		color_map {
			[0.3    rgb <0.4,0.4,0.5>]
			[0.8    rgb <0.3,0.3,0.4>]
			[1      rgb <0.6,0.6,0.7>]
		}
		frequency 6
		rotate <0,10,0>
		turbulence <0.05,0.05,0.05>
		octaves 6
		omega 0.7
		lambda 2
		scale 0.5
	}
	finish {
		ambient 0
		diffuse 0.3*3
		roughness 1
	}
	scale 2
}

#declare overlay =
texture {
	pigment {
		wrinkles
		turbulence 0.5
		color_map {
			[0      rgbt <0.1,0.1,0.12,1>]
			[0.2    rgbt <0.10,0.1,0.12,0.6>]
			[0.45   rgbt <0.05,0.05,0.08,0.5>]
			[0.65   rgbt <0.1,0.1,0.15,0.5>]
			[0.8    rgbt <0.15,0.15,0.2,0.6>]
			[1      rgbt <0.15,0.15,0.2,1>]
		}
		frequency 1
	}
	scale 0.2*<3,4,2>
	finish {
		ambient 0
		diffuse 0.3*3
		specular 0
		roughness 0.0025
	}
}

#declare line =
texture {
	pigment {
		wood
		turbulence 0.001
		color_map {
			[0, 0.02	color Black transmit 0.5 color Black transmit 1]
			[0.02		color Clear]
		}
	}
	finish {
		ambient 0
		diffuse 0.3*3
		specular 0.1
		roughness 0.01
	}
}

#declare line2 =
texture {
	pigment {
		wood
		turbulence 0.05
		color_map {
			[0, 0.01	color Black transmit 0.2 color Black transmit 1]
			[0.01, 0.5      color Clear color Clear]
			[0.5, 0.51      color Black transmit 0.2 color Black transmit 1]
			[0.51		color Clear]
		}
		scale 2
	}
	finish {
		ambient 0
		diffuse 0.3*3
		specular 0.1
		roughness 0.0025
	}
}

#declare overlay2 =
texture {
	pigment {
		wrinkles
		turbulence 0.5
		color_map {
			[0      rgbt <0.5,0.5,0.6,1>]
			[0.2    rgbt <0.5,0.5,0.6,0.8>]
			[0.45   rgbt <0.1,0.1,0.16,0.6>]
			[0.65   rgbt <0.2,0.2,0.3,0.6>]
			[0.8    rgbt <0.3,0.3,0.5,0.8>]
			[1      rgbt <0.3,0.3,0.5,1>]
		}
		frequency 0.5
	}
	scale 0.15*<3,4,2>
	finish {
		ambient 0
		diffuse 0.4*3
		specular 0.3
		roughness 0.01
	}
}

#declare stone1 =
texture {base scale 0.5}
texture {overlay}
texture {line scale <2,2,1.4> rotate <10,65,-20> normal {wrinkles 0.1 scale 0.005}}
texture {line scale <1,2,1.4> rotate <10,65, 20> normal {wrinkles 0.1 scale 0.005}}
texture {line scale <1,1,1.4> rotate <10,25,-20> normal {wrinkles 0.1 scale 0.005}}

#declare old_pitted_steel_texture =
texture {
	pigment {
		granite scale 0.5 // AGATE works well for this too.
		color_map {
			[0     rgb vpow (0.8*<0.4,0.4,0.38>, 0.7)*1.2]
			[0.153 rgb vpow (<0.4,0.4,0.4>, 0.7)*1.2*1.2]
			[0.398 rgb vpow (0.5*<0.4,0.4,0.35>, 0.7)*1.2]
			[0.398 rgb vpow (0.2*<0.7,0.7,0.7>, 0.7)*1.2]
			[1     rgb vpow (<0.405,0.380,0.345>, 0.7)*1.2]
		}
	}
	normal {granite 0.7 scale 1}
	finish {diffuse 0.9}
	scale 0.02
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.55  old_pitted_steel_texture scale 1]
                        [0.8   stone1 scale 1.2]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#declare T6_ =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.48  old_pitted_steel_texture scale 1]
                        [0.8   stone1 scale 1.2]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 6) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Gary MacKinnon  Stone of Stennis  http://www.irtc.org/ftp/pub/stills/2002-08-31/jgmrock.zip

#local H	    = 1;
#local Lac      = 3;
#local Octs     = 3;
#local Offset   = 0;
#local T	    = 0;
#declare siz    = 0.3;

#declare jgmrock =
function {
	15*f_snoise3d ((x+2)*0.02, (y+6)*0.02, z*0.02)
	-0.5*f_hetero_mf (x*0.4, y*0.4, z, H, Lac, Octs, Offset, T, 1)
}

#declare T1_ =
texture {
	pigment {
		bozo
		color_map {
			[0      rgb 1]
			[0.46   rgb <0.95,0.68,0.71-0.2>]
			[1      rgb <0.94,0.64+0.3,0.59+0.3>*0.8]
		}
		turbulence 1.8
		scale 6
		scale <1,1,0.005>
	}
	normal {
		average
		normal_map {
			[1      pigment_pattern {wrinkles scale 0.4} bump_size 1.5 accuracy 0.001]
			[1      function {jgmrock (x,y,z)} 2 accuracy 0.001]
		}
	}
	finish {brilliance 1 ambient 0 diffuse 0.35 specular 0.1*4 roughness 0.001*4}
}

#declare old_pitted_steel_texture =
texture {
	pigment {
		granite scale 0.5 // AGATE works well for this too.
		color_map {
			[0     rgb vpow (0.8*<0.4,0.4,0.38>, 0.7)*1.2]
			[0.153 rgb vpow (<0.4,0.4,0.4>, 0.7)*1.2*1.2]
			[0.398 rgb vpow (0.5*<0.4,0.4,0.35>, 0.7)*1.2]
			[0.398 rgb vpow (0.2*<0.7,0.7,0.7>, 0.7)*1.2]
			[1     rgb vpow (<0.405,0.380,0.345>, 0.7)*1.2]
		}
	}
	normal {granite 0.7 scale 1}
	finish {diffuse 0.9}
	scale 0.02
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.57  old_pitted_steel_texture scale 1]
                        [0.8   T1_ scale 1.2]
                }
        }
	interior {ior 2.5}
	scale 1
}

#declare T6_ =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.47  old_pitted_steel_texture scale 1]
                        [0.8   T1_ scale 1.2]
                }
        }
	interior {ior 2.5}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 7) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Gail Shaw  Here there be Dragons  http://www.irtc.org/ftp/pub/stills/2001-08-31/dragons1.zip

#declare T_Pebbles2 =
texture {
        pigment {color VeryDarkBrown}
}
texture {
        pigment {
                granite
                turbulence 0.6
                color_map {
                        [0,     0.154   color rgbf <0.996,0.824,0.780,0.412>   color rgbf <0.996,0.698,0.624,0.412>]
                        [0.154, 0.308   color rgbf <0.996,0.698,0.624,0.412>   color rgbf <0.906,0.675,0.553,0.616>]
                        [0.308, 0.444   color rgbf <0.906,0.675,0.553,0.616>   color rgbf <0.996,0.682,0.604,0.412>]
                        [0.444, 0.615   color rgbf <0.996,0.682,0.604,0.412>   color rgbf <0.996,0.824,0.780,0.412>]
                        [0.615, 0.812   color rgbf <0.996,0.824,0.780,0.412>   color rgbf <0.973,0.627,0.627,0.600>]
                        [0.812, 1.001   color rgbf <0.973,0.627,0.627,0.600>   color rgbf <0.996,0.824,0.780,0.412>]
                }
        }
        scale <1.2,3,1.5> 
        rotate <70,0,30>
        normal {
	    	    average
	    	    normal_map {
	    		        [1      granite 0.1
	    			            omega 0.7
	    			            scale <0.04,0.04,0.04>*0.5
	    		        ]
	    		        [1      dents 1
	    			            scale <0.04,0.04,0.04>*0.5
	    		        ]
	    	    }
	    }           
}
texture {
        pigment {
                granite
                turbulence 0.6
                color_map {
                        [0,     0.216   color rgbf <0.812,0.812,0.812,0.835>   color rgbf <0.745,0.843,0.835,0.847>]
                        [0.216, 0.241   color rgbf <0.745,0.843,0.835,0.847>   color rgbf <0.404,0.337,0.337,0.463>]
                        [0.241, 0.267   color rgbf <0.404,0.337,0.337,0.463>   color rgbf <0.773,0.729,0.745,0.622>]
                        [0.267, 0.759   color rgbf <0.773,0.729,0.745,0.622>   color rgbf <0.914,0.843,0.725,0.651>]
                        [0.759, 0.784   color rgbf <0.914,0.843,0.725,0.651>   color rgbf <0.153,0.133,0.208,0.437>]
                        [0.784, 0.81    color rgbf <0.153,0.133,0.208,0.437>   color rgbf <0.812,0.812,0.812,0.835>]
                        [0.81,  1.001   color rgbf <0.812,0.812,0.812,0.835>   color rgbf <0.812,0.812,0.812,0.835>]
                }
        } 
        scale <3,3,4> 
        rotate <0,0,40>
        normal {
	    	    average
	    	    normal_map {
	    		        [1      granite 0.1
	    			            omega 0.7
	    			            scale <0.04,0.04,0.04>*0.5
	    		        ]
	    		        [1      dents 1
	    			            scale <0.04,0.04,0.04>*0.5
	    		        ]
	    	    }
	    }
}
texture {
        pigment {
                granite
                turbulence 0.8
                color_map {
                        [0,    0.5   color Clear color Clear]
                        [0.5,  0.54  color Clear color Black]
                        [0.54, 1     color Clear color Clear]
                }
        } 
        //finish {brilliance 1 ambient 0 diffuse 0.35 specular 0.1*4 roughness 0.001*4} 
	    finish {
	    	    specular albedo 0.2
	    	    roughness 0.005
	    	    brilliance 1
	    	    diffuse albedo 0.6
	    	    reflection {0.01, 0.1 fresnel on}
	    	    conserve_energy
	    }
	    scale <1,2,1.4> 
        rotate <10,0,-20>
	    normal {
	    	    average
	    	    normal_map {
	    		        [1      granite 0.1
	    			            omega 0.7
	    			            scale <0.04,0.04,0.04>*0.5
	    		        ]
	    		        [1      dents 1
	    			            scale <0.04,0.04,0.04>*0.5
	    		        ]
	    	    }
	    }        
}
 
#declare old_pitted_steel_texture =
texture {
	pigment {
		granite scale 0.5 // AGATE works well for this too.
		color_map {
			[0     rgb vpow (0.8*<0.4,0.4,0.38>, 0.7)*1.2]
			[0.153 rgb vpow (<0.4,0.4,0.4>, 0.7)*1.2*1.2]
			[0.398 rgb vpow (0.5*<0.4,0.4,0.35>, 0.7)*1.2]
			[0.398 rgb vpow (0.2*<0.7,0.7,0.7>, 0.7)*1.2]
			[1     rgb vpow (<0.405,0.380,0.345>, 0.7)*1.2]
		}
	}
	normal {granite 0.7 scale 1}
	finish {diffuse 0.9}
	scale 0.02
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.63  old_pitted_steel_texture scale 1]
                        [0.8   T_Pebbles2 scale 8]
                }
        }
	    interior {ior 1.5}
	    scale 1
}
 
#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.47  old_pitted_steel_texture scale 1]
                        [0.8   T_Pebbles2 scale 8]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 8) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Glazed ceramic  
// inspired by Sean Day  decoy  http://news.povray.org/povray.binaries.scene-files/attachment/%3Cweb.53da248f183fb6647dded57b0%40news.povray.org%3E/decoy.zip

#declare Glaz3 =
texture {
	pigment {
		granite
		omega 0.8
		turbulence 0.4
		scale <0.04,0.04,0.04>*0.5
		color_map {
			[0.2    rgb <33,46,64>/255]
			[0.8    rgb <66,88,100>/555]
		}
	}
	finish {
		specular albedo 0.3
		roughness 0.02
		brilliance 2.2
		diffuse albedo 0.6
		reflection {0.01, 0.2 fresnel on}
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 0.1
				omega 0.7
				scale <0.04,0.04,0.04>*0.5
			]
			[1      dents 1
				scale <0.04,0.04,0.04>*0.5
			]
		}
	}
}

#declare Glaz2 =
texture {
	pigment {
		granite
		omega 0.8
		turbulence 0.4
		scale <0.04,0.04,0.04>*0.5
		color_map {
			[0.2    rgb <181,186,177>/255]
			[0.8    rgb <159,179,176>/255]
		}
	}
	finish {
		specular albedo 0.3
		roughness 0.02
		brilliance 2.2
		diffuse albedo 0.6
		reflection {0.01, 0.2 fresnel on}
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 0.1
				omega 0.7
				scale <0.04,0.04,0.04>*0.5
			]
			[1      dents 1
				scale <0.04,0.04,0.04>*0.5
			]
		}
	}
}

#declare Glaz1 =
texture {
	pigment {
		granite
		omega 0.8
		turbulence 0.4
		scale <0.04,0.04,0.04>*0.5
		color_map {
			[0.2    rgb <207,173,90>/255]
			[0.8    rgb <200,167,95>/255]
		}
	}
	finish {
		specular albedo 0.3
		roughness 0.02
		brilliance 2.2
		diffuse albedo 0.6
		reflection {0.01, 0.2 fresnel on}
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 0.1
				omega 0.7
				scale <0.04,0.04,0.04>*0.5
			]
			[1      dents 1
				scale <0.04,0.04,0.04>*0.5
			]
		}
	}
}

#macro halton (index, base) 

#local out = 0;
#local fraction = 1/base;
#local i = index;
#while (i > 0)
	#local remainder = mod (i, base);
	#local out = out+(fraction*remainder);
	#local i = int (i/base);
	#local fraction = fraction/base;
#end

out

#end

#declare s = seed (12);
#declare Dust =
texture {
	pigment {
		granite
                scale 0.001
                color_map {
                        [0      rgb <189,194,189>/255]
                        [1      rgb <199,207,204>/255]
                }
	}
	finish {diffuse 0.6}
	normal {
		average
		normal_map {
			#declare m = 24;
			#declare n = 0;
			#while ( n < m )
				[1      crackle m 
                                        solid 
                                        scale <0.2,10,0.2>*20 
                                        rotate <halton (n, 2)*360, halton (n, 3)*360, halton (n, 5)*360>
                                ]
				#declare n = n+1;
			#end
		}
	}
	scale 0.02*2
}

#declare wGlaz =
texture {
	pigment {
		agate
		agate_turb 1.0
		color_map {
			[0	rgb <239,224,186>/255]
			[1	rgb <243,225,187>/255]
		}
		turbulence 0.3
		octaves 10
		omega 0.7
		ramp_wave
	}
	normal {
		agate 0.1
		agate_turb 1.0
		turbulence 0.3
		octaves 10
		omega 0.7
		ramp_wave
	}
	finish {
		ambient 0
		diffuse 0.6
	}
        scale 0.3
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map { 
                	[0.66  Dust scale 4]
                	[0.68  Glaz3 scale 4]
                	[0.74  Glaz3 scale 4]
                	[0.77  Glaz2 scale 4]
                	[0.78  Glaz1 scale 4]
                        [0.79  wGlaz scale 4]                        
                }
        }
	interior {ior 2.5}
	scale 1
} 

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.55  Dust scale 4]
                	[0.6   Glaz3 scale 4]
                	[0.76  Glaz3 scale 4]
                	[0.78  Glaz2 scale 4]
                	[0.80  Glaz1 scale 4]
                        [0.82  wGlaz scale 4]
                }
        }
	interior {ior 2.5}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 9) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// inspired from Trevor G Quayle  Smilin' Buddha - take 2  http://news.povray.org/povray.binaries.images/thread/%3Cweb.4da0f47f7bc899ffb05ef170%40news.povray.org%3E/

#local P_Porcelain1 =
pigment {
	wrinkles
	poly_wave 1.4
	warp {turbulence 0.4 omega 0.55 octaves 7}
	color_map {
		[0      rgb <0.29-0.09,0.05-0.03,0>]
		[0.6    rgb <1,0.80+0.04,0.73>]
	}
	scale 0.002
}

#local P_Porcelain2 =
pigment {
	wrinkles
	poly_wave 1.4
	warp {turbulence 0.4 omega 0.55 octaves 7}
	color_map {
		[0.8    rgb <0.29-0.09,0.05-0.03,0>]
		[1      rgb <1,0.8+0.040,0.73>]
	}
	scale 0.002
}

#local N_Porcelain =
normal {
	average
	normal_map {
		[1      bozo 0.6 scale 0.018]
		[1      bozo 0.6 scale 0.006]
		[1      bozo 0.6 scale 0.002]
	}
}

#local F_Porcelain =
finish {
	ambient 0
	diffuse 0.55+0.25
	brilliance 1.5
	specular 0.7
	roughness 0.001
	reflection {0, 0.5 fresnel on}
	conserve_energy
}

#local T_Porcelain1 =
texture {
	pigment {P_Porcelain1}
	normal {N_Porcelain}
	finish {F_Porcelain}
}

#local T_Porcelain2 =
texture {
	pigment {P_Porcelain2}
	normal {N_Porcelain}
	finish {F_Porcelain}
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.72  T_Porcelain2 scale 4]
                        [0.88  T_Porcelain1 scale 4]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.74  T_Porcelain2 scale 4]
                        [0.92  T_Porcelain1 scale 4]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 10) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Abe  boulders  http://news.povray.org/povray.binaries.scene-files/message/%3Cweb.449423ac72d4de73273c6a720%40news.povray.org%3E/#%3Cweb.449423ac72d4de73273c6a720%40news.povray.org%3E

#declare RockTex =
texture {
	pigment {
		wrinkles//slope y
		cubic_wave
		color_map {
			[0      rgb 0.25]
			[1      rgb 0.60]
		}
	}
	normal {
		pigment_pattern {
			wrinkles
			scale 0.35
			poly_wave 3
		}
		//wrinkles  scale 0.1 poly_wave 2
		bump_size 1.8
		accuracy 0.001
	}
	finish {ambient 0 diffuse 0.6*1.5 brilliance 1}
}

#declare f_absnoise3d = function {pow (abs (2*f_noise3d (x,y,z)-1),0.3)}
#declare Spots = function {pattern {crackle form x}}

#macro Turb ()

scale 2
warp {turbulence 1 lambda 3 octaves 3}
scale 0.5
scale 0.05

#end

#macro LichenPig (Ltcol, Medcol, Dkcol, Coverage)

pigment_pattern {
	function {Spots (x,y,z)}
	color_map {
		[0	  rgb 1]
		[Coverage rgb 0]
	}
	translate 10
	scale 2
	warp {turbulence 0.3 lambda 2.5 octaves 4}
	scale 0.5
	scale 1.5
}
pigment_map {
	[0      function {f_noise3d (x,y,z)}
		Turb ()
		color_map {
			[0      rgb Ltcol transmit 1]
			[1      rgb Dkcol transmit 1]
		}
	]
	[0.01   function {f_noise3d (x,y,z)}
		Turb ()
		color_map {
			[0      rgb Ltcol transmit 0]
			[1      rgb Dkcol transmit 0]
		}
	]
	[0.15   function {f_absnoise3d (x,y,z)}
		Turb ()
		color_map {
			[0.05   rgb Medcol transmit 1]
			[0.05   rgb Medcol transmit 0]
			[1      rgb Dkcol  transmit 0]
		}
	]
}
scale 0.25

#end

#declare LichenLt  = vpow (<0.6431,0.6863,0.5686>,1.8);
#declare LichenMed = vpow (<0.5451,0.5843,0.4863>,1.8);
#declare LichenDk  = vpow (<0.3569,0.4235,0.3137>,1.8);

#declare LichenTex2 =
texture {
	pigment {
		wrinkles//planar
		pigment_map {
			#local i = 0;
			#while (i < 100)
				[i*0.01   LichenPig (LichenLt, LichenMed, LichenDk, 1.5*0.15*(i*0.01))]
				#local i = i+1;
			#end
		}
	}
	normal {
		pigment_pattern {
			planar
			pigment_map {
				#local i = 0;
				#while (i < 100)
					[i*0.01 average
						pigment_map {
							[1      LichenPig (0.5, 1, 0, 1.5*0.15*(i*0.01))]
							[1      pigment_pattern {wrinkles scale 0.25 poly_wave 2}]
						}
					]
					#local i = i+1;
				#end
			}
		}
		accuracy 0.005
		bump_size 0.25*2
	}
	finish {ambient 0 diffuse 0.6*1.5 brilliance 2}
}

#declare LichenTex3 =
texture {
	pigment {
		wrinkles//planar
		pigment_map {
			#local i = 0;
			#while (i < 100)
				[i*0.01   LichenPig (LichenLt, LichenMed, LichenDk, 1.5*0.3*(i*0.01))]
				#local i = i+1;
			#end
		}
	}
	normal {
		pigment_pattern {
			planar
			pigment_map {
				#local i = 0;
				#while (i < 100)
					[i*0.01 average
						pigment_map {
							[1      LichenPig (0.5, 1, 0, 1.5*0.3*(i*0.01))]
							[1      pigment_pattern {wrinkles scale 0.25 poly_wave 2}]
						}
					]
					#local i = i+1;
				#end
			}
		}
		accuracy 0.005
		bump_size 0.25*2
	}
	finish {ambient 0 diffuse 0.6*1.5 brilliance 2}
}

#declare LichenTex4 =
texture {
	pigment {
		wrinkles//planar
		pigment_map {
			#local i = 0;
			#while (i < 100)
				[i*0.01   LichenPig (LichenLt, LichenMed, LichenDk, 1.5*0.45*(i*0.01))]
				#local i = i+1;
			#end
		}
	}
	normal {
		pigment_pattern {
			planar
			pigment_map {
				#local i = 0;
				#while (i < 100)
					[i*0.01 average
						pigment_map {
							[1      LichenPig (0.5, 1, 0, 1.5*0.45*(i*0.01))]
							[1      pigment_pattern {wrinkles scale 0.25 poly_wave 2}]
						}
					]
					#local i = i+1;
				#end
			}
		}
		accuracy 0.005
		bump_size 0.25*2
	}
	finish {ambient 0 diffuse 0.6*1.5 brilliance 2}
}

#declare LichenTex5 =
texture {
	pigment {
		wrinkles//planar
		pigment_map {
			#local i = 0;
			#while (i < 100)
				[i*0.01   LichenPig (LichenLt, LichenMed, LichenDk, 1.5*0.6*(i*0.01))]
				#local i = i+1;
			#end
		}
	}
	normal {
		pigment_pattern {
			planar
			pigment_map {
				#local i = 0;
				#while (i < 100)
					[i*0.01 average
						pigment_map {
							[1      LichenPig (0.5, 1, 0, 1.5*0.6*(i*0.01))]
							[1      pigment_pattern {wrinkles scale 0.25 poly_wave 2}]
						}
					]
					#local i = i+1;
				#end
			}
		}
		accuracy 0.005
		bump_size 0.25*2
	}
	finish {ambient 0 diffuse 0.6*1.5 brilliance 2}
}

#declare LichenTex6 =
texture {
	pigment {
		wrinkles//planar
		pigment_map {
			#local i = 0;
			#while (i < 100)
				[i*0.01   LichenPig (LichenLt, LichenMed, LichenDk, 1.5*0.75*(i*0.01))]
				#local i = i+1;
			#end
		}
	}
	normal {
		pigment_pattern {
			planar
			pigment_map {
				#local i = 0;
				#while (i < 100)
					[i*0.01 average
						pigment_map {
							[1      LichenPig (0.5, 1, 0, 1.5*0.75*(i*0.01))]
							[1      pigment_pattern {wrinkles scale 0.25 poly_wave 2}]
						}
					]
					#local i = i+1;
				#end
			}
		}
		accuracy 0.005
		bump_size 0.25*2
	}
	finish {ambient 0 diffuse 0.6*1.5 brilliance 2}
}

#declare LichenTex7 =
texture {
	pigment {
		wrinkles//planar
		pigment_map {
			#local i = 0;
			#while (i < 100)
				[i*0.01   LichenPig (LichenLt, LichenMed, LichenDk, 1.5*0.9*(i*0.01))]
				#local i = i+1;
			#end
		}
	}
	normal {
		pigment_pattern {
			planar
			pigment_map {
				#local i = 0;
				#while (i < 100)
					[i*0.01 average
						pigment_map {
							[1      LichenPig (0.5, 1, 0, 1.5*0.9*(i*0.01))]
							[1      pigment_pattern {wrinkles scale 0.25 poly_wave 2}]
						}
					]
					#local i = i+1;
				#end
			}
		}
		accuracy 0.005
		bump_size 0.25*2
	}
	finish {ambient 0 diffuse 0.6*1.5 brilliance 2}
}

#declare boulders1 =
texture {RockTex}

#declare boulders2 =
texture {RockTex}
texture {LichenTex2}

#declare boulders3 =
texture {RockTex}
texture {LichenTex3}

#declare boulders4 =
texture {RockTex}
texture {LichenTex4} 

#declare boulders5 =
texture {RockTex}
texture {LichenTex5}

#declare boulders6 =
texture {RockTex}
texture {LichenTex6}

#declare boulders7 =
texture {RockTex}
texture {LichenTex7}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.51  boulders1 scale 8]
                        [0.59  boulders2 scale 8]
                        [0.67  boulders3 scale 8]
                        [0.71  boulders4 scale 8] 
                        [0.75  boulders5 scale 8]
                        [0.775 boulders6 scale 8]
                        [0.8   boulders7 scale 8]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.63  boulders1 scale 8]
                        [0.67  boulders2 scale 8]
                        [0.71  boulders3 scale 8]
                        [0.745 boulders4 scale 8]
                        [0.78  boulders5 scale 8]
                        [0.815 boulders6 scale 8]
                        [0.85  boulders7 scale 8]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 11) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Sean Day  decoy  http://news.povray.org/povray.binaries.scene-files/attachment/%3Cweb.53da248f183fb6647dded57b0%40news.povray.org%3E/decoy.zip

#declare brownCeramic =
texture {
	pigment {
		granite
		omega 0.8
		turbulence 0.4
		scale <0.02,0.1,0.02>
		color_map {
			[0      rgb Ga (<0.04,0.013,0.001>)]
			[0.45   rgb Ga (<0.02,0.01,0.0002>)]
			[0.9    rgb Ga (<0.2,0.085,0.01>*1.5)]
		}
	}
	finish {
		specular albedo 0.3
		roughness 0.02
		brilliance 4.2
		diffuse albedo 0.35*3
		reflection {0.01, 0.2 fresnel on}
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 0.1
				omega 0.7
				scale <0.02,0.1,0.02>
			]
			[1      dents 1
				scale <0.02,0.1,0.02>
			]
		}
	}
}

#declare lightCeramic =
texture {
	pigment {
		granite
		omega 0.8
		turbulence 0.4
		scale <0.02,0.1,0.02>
		color_map {
			[0      rgb Ga (<0.3,0.165,0.05>*1.5)]
			[0.45   rgb Ga (<0.2,0.085,0.01>*1.5)]
			[0.8    rgb Ga (<0.04,0.015,0.001>)]
		}
	}
	finish {
		specular albedo 0.3
		roughness 0.02
		brilliance 2.2
		diffuse albedo 0.45*3
		reflection {0.01, 0.2 fresnel on}
		conserve_energy
	}
	normal {
		average
		normal_map {
			[1      granite 0.1
				omega 0.7
				scale <0.02,0.1,0.02>
			]
			[1      dents 1
				scale <0.02,0.1,0.02>
			]
		}
	}
}

#declare I1 =
interior {ior 1.53}

#macro M1 (t_offset)

texture_map {
	[0.45   lightCeramic scale 3]
	[0.55   brownCeramic scale 3]
}

#end  

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                        [0.72   brownCeramic scale 12]
                        [0.88   lightCeramic scale 12]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                        [0.74   brownCeramic scale 12]
                        [0.92   lightCeramic scale 12]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 12) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Tekno Frannansa  Smooth CSG  http://news.povray.org/povray.binaries.scene-files/attachment/%3Cweb.4f564c38fa81888da4faf9d60%40news.povray.org%3E/smooth_csg.zip

#declare wGlaz1 =
texture {
	pigment {
		agate
		agate_turb 1
		color_map {
			[0	rgb <239,224,206>/255]
			[1	rgb <243,225,207>/255]
		}
		turbulence 0.3
		octaves 10
		omega 0.7
		ramp_wave
	}
	normal {
		agate 0.05
		agate_turb 1.0
		turbulence 0.3
		octaves 10
		omega 0.7
		ramp_wave
	}
	finish {
		ambient 0
		diffuse 0.4
	}
        scale 0.5
}

#declare wGlaz2 =
texture {
	pigment {
		agate
		agate_turb 1
		color_map {
			[0	rgb <239,224,206>/255]
			[1	rgb <243,225,207>/255]
		}
		turbulence 0.3
		octaves 10
		omega 0.7
		ramp_wave
	}
	normal {
                average 
                normal_map {
                        [1      agate 0.1
		                agate_turb 1
		                turbulence 0.3
		                octaves 10
		                omega 0.7
		                ramp_wave
                        ]
                        [1      crackle -6 
                                form <0.9,0.4,-0.3> 
                                scale 0.4 warp {turbulence 0.1} scale 0.25
                        ]
                }
	}
	finish {
		ambient 0
		diffuse 0.4
	}
        scale 0.5
}

#declare Color1 = rgb <0.2,0.3,0.1>;

#declare moss1 =
texture {
	average
	texture_map {
		[1      pigment {
				bozo
				color_map {
					[0      color Color1*0.9]
					[1      color Color1*1.1]
				}
				scale 0.001
			}
			normal {
				average
				normal_map {
					[1      bumps 0.15
						warp {turbulence 1}
						scale 0.2
					]
					[1      bumps 0.1
						warp {turbulence 0.5}
						scale 0.001
					]
                                        [1      wrinkles 4.5 scale 0.05]
				}
			}
			finish {ambient 0 diffuse 0.6*2 brilliance 0.6}
		]
		[1      pigment {color -Color1}
			finish {ambient 0 diffuse 0 phong 0.5 phong_size 2 metallic}
		]
	}
        scale 0.5
}

#declare Color2 = rgb <0.1,0.16,0.06>;
	
#declare moss2 =
texture {
	average
	texture_map {
		[1      pigment {
				bozo
				color_map {
					[0      color Color2*0.9]
					[1      color Color2*1.1]
				}
				scale 0.001
			}
			normal {
				average
				normal_map {
					[1      bumps 0.15
						warp {turbulence 1}
						scale 0.2
					]
					[1      bumps 0.1
						warp {turbulence 0.5}
						scale 0.001
					]
                                        [1      wrinkles 6 scale 0.05]
				}
			}
			finish {ambient 0 diffuse 0.6*2 brilliance 0.6}
		]
		[1      pigment {color -Color2}
			finish {ambient 0 diffuse 0 phong 0.5 phong_size 2 metallic}
		]
	}
        scale 0.5
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.57  moss2 scale 4]
                        [0.69  moss1 scale 4]
                        [0.77  wGlaz1 scale 4]
                        [0.93  wGlaz2 scale 4]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.55  moss2 scale 4]
                        [0.7   moss1 scale 4]
                        [0.8   wGlaz1 scale 4]
                        [0.95  wGlaz2 scale 4]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 13) #declare light_ = 0.4; /////////////////////////////////////////////////////////////////////////////////////

// Dave Sproson  Just Playing  http://news.povray.org/povray.binaries.images/message/%3C40895095%241%40news.povray.org%3E/#%3C40895095%241%40news.povray.org%3E

#declare a =
texture {
         pigment {color rgb <0.5,0.5,1>}
         finish {
                ambient 0
                emission 0
                diffuse 0.3
                reflection {
                        0.35*0.4, 0.5*0.4
                        falloff  1
                        exponent 1
                        metallic 0
                }
         }
}

#declare b =
texture {
        pigment {color rgb <0.35,0.6,1>}
        finish {
                emission 0.9
                diffuse 0.25
                brilliance 0.1
                irid {
                        0.2
                        thickness 0.5
                        turbulence 0
                }
        }
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                        [0.76   a scale 4]
                        [0.82   b scale 4]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                        [0.79   a scale 4]
                        [0.85   b scale 4]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 14) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// dark $ dirty stone

//__________________________________________________________________________________________________________________________

//------------ Rose & cream yellow
#declare T_Grnt18 =
texture {
 pigment {
  granite
  turbulence 0.4
  color_map {
    [0.000, 0.202   color rgbt <1.000, 0.718, 0.541, 0.000>
                    color rgbt <0.890, 0.651, 0.612, 0.000>]
    [0.202, 0.298   color rgbt <0.890, 0.651, 0.612, 0.000>
                    color rgbt <1.000, 0.820, 0.675, 0.000>]
    [0.298, 0.377   color rgbt <1.000, 0.820, 0.675, 0.000>
                    color rgbt <0.890, 0.643, 0.612, 0.000>]
    [0.377, 0.465   color rgbt <0.890, 0.643, 0.612, 0.000>
                    color rgbt <0.937, 0.729, 0.561, 0.000>]
    [0.465, 0.544   color rgbt <0.937, 0.729, 0.561, 0.000>
                    color rgbt <0.878, 0.604, 0.565, 0.000>]
    [0.544, 0.640   color rgbt <0.878, 0.604, 0.565, 0.000>
                    color rgbt <0.984, 0.780, 0.655, 0.000>]
    [0.640, 0.860   color rgbt <0.984, 0.780, 0.655, 0.000>
                    color rgbt <1.000, 0.863, 0.635, 0.000>]
    [0.860, 0.982   color rgbt <1.000, 0.863, 0.635, 0.000>
                    color rgbt <1.000, 0.765, 0.620, 0.000>]
    [0.982, 1.001   color rgbt <1.000, 0.765, 0.620, 0.000>
                    color rgbt <1.000, 0.718, 0.541, 0.000>]
   }
 }
 }

//--------- Gray Marble with White feather Viens
#declare T_Grnt19 =
texture {
 pigment {
  granite
  turbulence 0.0
  color_map {
    [0.0, 0.3 color White color DimGray]
    [0.3, 0.4 color DimGray color DimGray]
    [0.4, 0.6 color DimGray color DimGray]
    [0.6, 1.0 color DimGray color DimGray]
   }
 }
 finish {
  crand 0.02
 }
 }

//--------- White Marble with Gray feather Viens
#declare T_Grnt20 =
texture {
 pigment {
  granite
  turbulence 0.0
  color_map {
    [0.0, 0.3 color Mica color White]
    [0.3, 0.4 color White color White]
    [0.4, 0.6 color White color White]
    [0.6, 1.0 color White color White]
   }
 }
 finish {
  crand 0.02
 }
 }

//------------- Peach & Yellow Marble with white veining
#declare T_Stone16 =
texture {T_Grnt18 scale <1.3,2,2>*0.25 rotate <0,0,-30>
        finish {ambient 0 diffuse 0.3 crand 0.03}
}
texture {T_Grnt19 scale <2,4,2>*0.25 rotate <0,0,-30>
        finish {ambient 0 diffuse 0.3 crand 0.03}
}
texture {T_Grnt20 scale <1,2,1>*0.25 rotate <0,0,40>
        finish {phong 1 phong_size 90 diffuse 0.2}
}

#declare old_pitted_steel_texture =
texture {
	pigment {
		granite scale 0.5 // AGATE works well for this too.
		color_map {
			[0     rgb vpow (0.8*<0.4,0.4,0.38>, 0.7)*1.2]
			[0.153 rgb vpow (<0.4,0.4,0.4>, 0.7)*1.2*1.2]
			[0.398 rgb vpow (0.5*<0.4,0.4,0.35>, 0.7)*1.2]
			[0.398 rgb vpow (0.2*<0.7,0.7,0.7>, 0.7)*1.2]
			[1     rgb vpow (<0.405,0.380,0.345>, 0.7)*1.2]
		}
	}
	normal {granite 0.7 scale 1}
	finish {diffuse 0.9}
	scale 0.02
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.6    old_pitted_steel_texture scale 1]
                        [0.8    T_Stone16 scale 4]
                }
        }
	interior {ior 1.5}
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.55   old_pitted_steel_texture scale 1]
                        [0.77   T_Stone16 scale 4]
                }
        }
	interior {ior 1.5}
	scale 1
} 

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 15) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// silver

global_settings {irid_wavelength srgb <1,0.01,0.01>}

#declare silver1 =
texture {
        pigment {color srgb <1,0.952,0.818>}
	normal {
                average
                normal_map {
                        [1      wrinkles 0.05 scale 0.02]
                        [1      wrinkles 0.05 scale 0.063]
                        [1      wrinkles 0.05 scale 0.2]
                }
        }
        finish { 
                brilliance 2
                specular 0.5 
                roughness 0.01
                metallic 
                reflection {0.8 metallic} 
                ambient 0 
                diffuse 0.05 
                conserve_energy 
        }
}

#declare mtex =
texture {
        pigment {color srgb <1,0.952,0.818>}
	normal {
                average
                normal_map {
                        [1      wrinkles 0.15 scale 0.02]
                        [1      wrinkles 0.15 scale 0.063]
                        [1      wrinkles 0.15 scale 0.2]
                }
        }
        finish { 
                brilliance 2
                specular 0.5 
                roughness 0.01
                metallic 
                reflection {0.8 metallic} 
                ambient 0 
                diffuse 0.05 
                conserve_energy
        }
}

#declare dtex =
texture {
        pigment {color srgb 1}
        normal {bumps 0.2 sine_wave scale 0.01}
        finish { 
                brilliance 1
                specular 0.3 
                roughness 0.03 
                reflection {0, 0.8 fresnel on} 
                ambient 0 
                diffuse 0.15 
                conserve_energy
        }
}

#declare silver2 =
texture {
        pigment_pattern {
                average
                pigment_map {
                        [1      wrinkles scale 0.02]
                        [1      wrinkles scale 0.063]
                        [1      wrinkles scale 0.2]
                }
        }
        texture_map {
                [0.3    mtex]
                [1      dtex]
        }
} 

#declare mtex3 =
texture {
        pigment {color srgb <1,0.952,0.818>}
	normal {
                average
                normal_map {
                        [1      wrinkles 0.15 scale 0.02]
                        [1      wrinkles 0.15 scale 0.063]
                        [1      wrinkles 0.15 scale 0.2]
                }
        }
        finish { 
                brilliance 2
                specular 0.5 
                roughness 0.01
                metallic 
                reflection {0.8 metallic} 
                ambient 0 
                diffuse 0.05 
                conserve_energy
                irid {0.15 thickness 0.5 turbulence 0.9} 
        }
}

#declare dtex3 =
texture {
        pigment {color srgb 0.3}
        normal {bumps 0.2 sine_wave scale 0.01}
        finish { 
                brilliance 1
                specular 0.2 
                roughness 0.03 
                reflection {0, 0.2 fresnel on} 
                ambient 0 
                diffuse 0.3 
                conserve_energy
                irid {0.15 thickness 0.5 turbulence 0.9} 
        }
}

#declare silver3 =
texture {
        pigment_pattern {
                average
                pigment_map {
                        [1      wrinkles scale 0.02]
                        [1      wrinkles scale 0.063]
                        [1      wrinkles scale 0.2]
                }
        }
        texture_map {
                [0.2    mtex3]
                [0.8    dtex3]
        }
}
	                           
#declare silver4 =
texture {
        pigment {color srgb 0.1}
        normal {bumps 0.8 sine_wave scale 0.001}
        finish { 
                brilliance 1
                specular 0.2 
                roughness 0.03 
                reflection {0, 0.1 fresnel on} 
                ambient 0 
                diffuse 0.2
                conserve_energy
                irid {0.1 thickness 0.5 turbulence 0.9} 
        }
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.67  silver4 scale 4]
                	[0.695 silver3 scale 4]
                	[0.72  silver2 scale 4]
                        [0.75  silver1 scale 4]
                }
        }
	interior {ior 2.5}
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.59  silver4 scale 4]
                	[0.67  silver3 scale 4]
                	[0.73  silver2 scale 4]
                        [0.79  silver1 scale 4]
                }
        }
	interior {ior 2.5}
	scale 1
} 

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 16) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// hexpigment nestprox

#declare Hexcolor = array [3] {rgb <0.91,0.76,0.65>+<0,0.1,0.22>, rgb <0.96,0.8,0.69>-<0,0.1,0>, rgb <0.858824,0.576471,0.439216>+<0,0.1,0.2>}     //LightWood, Flesh, Tan}

#declare stone_clear =
texture {
	pigment {
		hexagon
		color Hexcolor [0]
		color Hexcolor [1]
		color Hexcolor [2]
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.45
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.5}
		pigment {color Hexcolor [1] transmit 0.5}
		pigment {color Hexcolor [2] transmit 0.5}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.15
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.6667}
		pigment {color Hexcolor [1] transmit 0.6667}
		pigment {color Hexcolor [2] transmit 0.6667}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.05
	}
	normal {
		average
		normal_map {
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.45]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.15]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.05]
			[1      crackle 36 scale 0.1 form <1,0.7,0>]
		}
		scale 0.1
	}
	finish {
		ambient 0
		specular 0.2
		roughness 0.003
		diffuse 0.8
		reflection {0, 0.2 fresnel on}
		conserve_energy
	}
}

#declare stone_moss1 =
texture {
	pigment {
		hexagon
		color Hexcolor [0]
		color Hexcolor [1]
		color Hexcolor [2]
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.15
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.5}
		pigment {color Hexcolor [1] transmit 0.5}
		pigment {color Hexcolor [2] transmit 0.5}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.05
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.6667}
		pigment {color Hexcolor [1] transmit 0.6667}
		pigment {color Hexcolor [2] transmit 0.6667}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.0167
	}
	normal {
		average
		normal_map {
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.15]  
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.05]  
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.0167]
			[1      crackle 36 scale 0.1 form <1,0.7,0>]
		}
		scale 0.1
	} 
	finish {
		ambient 0
		specular 0.2
		roughness 0.003
		diffuse 0.8
		reflection {0, 0.2 fresnel on}
		conserve_energy
	} 
}
texture {
	pigment {
		crackle 
                form <-0.9,0.1,0.3>
		turbulence 0.5
		color_map {
			[0.1      rgbt 1]
                        [0.4*0.3  rgbt <0.150-0.02,0.225+0.02,0.0250,0.30>]
			[0.4*0.35 rgbt <0.030-0.02,0.020+0.02,0.0025,0.20>]
			[0.4*0.4  rgbt <0.030-0.02,0.020+0.02,0.0025,0.10>]
			[0.4*0.45 rgbt <0.150-0.02,0.225+0.02,0.0250,0.35>]
			[0.4*0.5  rgbt <0.185-0.02,0.275+0.02,0.0250,0.35>]
			[0.4*0.55 rgbt <0.200-0.02,0.300+0.02,0.0350,0.40>]
			[0.4      rgbt <0.050-0.02,0.020+0.02,0.0035,0.10>]
		}
		scale 0.012
	}
	normal {crackle 9 form <1,0.7,0> scale 0.001}   // granite 0.7 scale 0.005}
	finish {ambient 0 specular 0.15 roughness 0.05 diffuse 1 brilliance 1.2 reflection {0.01, 0.005 fresnel on} conserve_energy}
}

#declare stone_moss2 =
texture {
	pigment {
		hexagon
		color Hexcolor [0]
		color Hexcolor [1]
		color Hexcolor [2]
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.15
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.5}
		pigment {color Hexcolor [1] transmit 0.5}
		pigment {color Hexcolor [2] transmit 0.5}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.05
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.6667}
		pigment {color Hexcolor [1] transmit 0.6667}
		pigment {color Hexcolor [2] transmit 0.6667}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.0167
	}
	normal {
		average
		normal_map {
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.15]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.05]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.0167]
			[1      crackle 36 scale 0.1 form <1,0.7,0>]
		}
		scale 0.1
	} 
	finish {
		ambient 0
		specular 0.2
		roughness 0.003
		diffuse 0.8
		reflection {0, 0.2 fresnel on}
		conserve_energy
	}
}
texture {
	pigment {
		crackle 
                form <-0.9,0.3,0.3>
		turbulence 0.5
		color_map {
			[0.1      rgbt 1]
                        [0.4*0.3  rgbt <0.150-0.02,0.225+0.02,0.0250,0.30>]
			[0.4*0.35 rgbt <0.030-0.02,0.020+0.02,0.0025,0.20>]
			[0.4*0.4  rgbt <0.030-0.02,0.020+0.02,0.0025,0.10>]
			[0.4*0.45 rgbt <0.150-0.02,0.225+0.02,0.0250,0.35>]
			[0.4*0.5  rgbt <0.185-0.02,0.275+0.02,0.0250,0.35>]
			[0.4*0.55 rgbt <0.200-0.02,0.300+0.02,0.0350,0.40>]
			[0.4      rgbt <0.050-0.02,0.020+0.02,0.0035,0.10>]
		}
		scale 0.012
	}
	normal {crackle 9 form <1,0.7,0> scale 0.001}   // granite 0.7 scale 0.005}
	finish {ambient 0 specular 0.15 roughness 0.05 diffuse 1 brilliance 1.2 reflection {0.01, 0.005 fresnel on} conserve_energy}
}

#declare stone_moss3 =
texture {
	pigment {
		hexagon
		color Hexcolor [0]
		color Hexcolor [1]
		color Hexcolor [2]
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.15
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.5}
		pigment {color Hexcolor [1] transmit 0.5}
		pigment {color Hexcolor [2] transmit 0.5}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.05
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.6667}
		pigment {color Hexcolor [1] transmit 0.6667}
		pigment {color Hexcolor [2] transmit 0.6667}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.0167
	}
	normal {
		average
		normal_map {
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.15]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.05]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.0167]
			[1      crackle 36 scale 0.1 form <1,0.7,0>]
		}
		scale 0.1
	} 
	finish {
		ambient 0
		specular 0.2
		roughness 0.003
		diffuse 0.8
		reflection {0, 0.2 fresnel on}
		conserve_energy
	}
}
texture {
	pigment {
		crackle 
                form <-0.9,0.5,0.3>
		turbulence 0.5
		color_map {
			[0.1      rgbt 1]
                        [0.4*0.3  rgbt <0.150-0.02,0.225+0.02,0.0250,0.30>]
			[0.4*0.35 rgbt <0.030-0.02,0.020+0.02,0.0025,0.20>]
			[0.4*0.4  rgbt <0.030-0.02,0.020+0.02,0.0025,0.10>]
			[0.4*0.45 rgbt <0.150-0.02,0.225+0.02,0.0250,0.35>]
			[0.4*0.5  rgbt <0.185-0.02,0.275+0.02,0.0250,0.35>]
			[0.4*0.55 rgbt <0.200-0.02,0.300+0.02,0.0350,0.40>]
			[0.4      rgbt <0.050-0.02,0.020+0.02,0.0035,0.10>]
		}
		scale 0.012
	}
	normal {crackle 9 form <1,0.7,0> scale 0.001}   // granite 0.7 scale 0.005}
	finish {ambient 0 specular 0.15 roughness 0.05 diffuse 1 brilliance 1.2 reflection {0.01, 0.005 fresnel on} conserve_energy}
}

#declare stone_moss4 =
texture {
	pigment {
		hexagon
		color Hexcolor [0]
		color Hexcolor [1]
		color Hexcolor [2]
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.15
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.5}
		pigment {color Hexcolor [1] transmit 0.5}
		pigment {color Hexcolor [2] transmit 0.5}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.05
	}
}
texture {
	pigment {
		hexagon
		pigment {color Hexcolor [0] transmit 0.6667}
		pigment {color Hexcolor [1] transmit 0.6667}
		pigment {color Hexcolor [2] transmit 0.6667}
		turbulence 4 lambda 4 omega 0.5 octaves 5
		scale 0.0167
	}
	normal {
		average
		normal_map {
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.15]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.05]
			[1      hexagon 4 turbulence 4 lambda 4 omega 0.5 octaves 5 scale 0.0167]
			[1      crackle 36 scale 0.1 form <1,0.7,0>]
		}
		scale 0.1
	} 
	finish {
		ambient 0
		specular 0.2
		roughness 0.003
		diffuse 0.8
		reflection {0, 0.2 fresnel on}
		conserve_energy
	}
}
texture {
	pigment {
		crackle 
                form <-0.9,0.7,0.3>
		turbulence 0.5
		color_map {
			[0.1      rgbt 1]
                        [0.4*0.3  rgbt <0.150-0.02,0.225+0.02,0.0250,0.30>]
			[0.4*0.35 rgbt <0.030-0.02,0.020+0.02,0.0025,0.20>]
			[0.4*0.4  rgbt <0.030-0.02,0.020+0.02,0.0025,0.10>]
			[0.4*0.45 rgbt <0.150-0.02,0.225+0.02,0.0250,0.35>]
			[0.4*0.5  rgbt <0.185-0.02,0.275+0.02,0.0250,0.35>]
			[0.4*0.55 rgbt <0.200-0.02,0.300+0.02,0.0350,0.40>]
			[0.4      rgbt <0.050-0.02,0.020+0.02,0.0035,0.10>]
		}
		scale 0.012
	}
	normal {crackle 9 form <1,0.7,0> scale 0.001}   // granite 0.7 scale 0.005}
	finish {ambient 0 specular 0.15 roughness 0.05 diffuse 1 brilliance 1.2 reflection {0.01, 0.005 fresnel on} conserve_energy}
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
	                [0.68   stone_moss4 scale 20]
	                [0.71   stone_moss3 scale 20]
	                [0.74   stone_moss2 scale 20]
	                [0.78   stone_moss1 scale 20] 
	                [0.82   stone_clear scale 20]
                }
        }
	interior {ior 1.5}
	scale 1
} 

#declare T6_ =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
	                [0.6    stone_moss4 scale 20]
	                [0.68   stone_moss3 scale 20]
	                [0.76   stone_moss2 scale 20]
	                [0.83   stone_moss1 scale 20] 
	                [0.9    stone_clear scale 20]
                }
        }
	interior {ior 1.5}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 17) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Iron texture by Mark Slone  Innocent Shadow  http://www.irtc.org/ftp/pub/stills/2002-12-31/ishadow.zip       
// Rust texture by Phil Brewer  quincy  http://www.irtc.org/ftp/pub/stills/2006-08-31/quincy.zip

#declare sponge_pig =
pigment {
        #local Curve    = 0.125; 
        #local Omega    = 0.5;
        #local Lambda   = 2;
        #local Octaves  = 8;
        pigment_pattern {
                average
                pigment_map {
                        #local octave = 0;
                        #while (octave < Octaves)
                                [pow (Omega, octave)
                                        pigment_pattern {
                                                crackle 
                                                form <0.9,0,0>
                                                scale pow (Lambda, -octave)
                                                color_map {
                                                        [0      rgb 1]
                                                        [1      rgb 0]
                                                }
                                        }
                                        poly_wave 1/Curve
                                ]
                                #local octave = octave+1;
                        #end
                }
        }
        poly_wave Curve
        color_map {
                [0.6    rgb 1]
                [1      rgb 0]
        }
}

#local IronPigment =
pigment {
	wrinkles
	color_map {
		[0      rgb <0.1,0.1,0.1>]
		[0.7    rgb <0.15,0.15,0.15>]
		[1      rgb <0.2,0.2,0.2>]
	}
	scale 5
}

#local IronTexture =
texture {
	pigment {IronPigment}
	normal {
                granite 
                0.2
        }
	finish {
		ambient 0
		roughness 0.015
		specular 0.2
		diffuse 1.2
		brilliance 2
		reflection {0.1, 0.3 fresnel on}
	}
}

#local RustPigment =
pigment {
	granite
	color_map {
		[0      rgb <0.71*0.9,0.3,0.11*1.1>*0.8]  
		[0.4    rgb <0.21*0.9,0.1,0.03*1.1>*1.2]  
		[0.6    rgb <0.21*0.9,0.1,0.03*1.1>*1.2]  
		[1      rgb <0.47*0.9,0.05,0.01*1.1>*0.9] 
	}
	scale 0.5
	turbulence 1
}

#local RustTexture =
texture {
	pigment {RustPigment}
	normal {
                granite 
                1
                scale 0.02
        }
        finish {ambient 0 diffuse 1.05}
}

#local RustTexture2 =
texture {
	pigment {
                RustPigment 
                warp {turbulence 1 omega 0.6 lambda 4} 
                scale <0.5,1,0.5>
        }
	normal {
                granite
                1 
                scale 0.02 
                warp {turbulence 1 omega 0.6 lambda 4} 
                scale <0.5,1,0.5>
        }
        finish {ambient 0 diffuse 1.05}
}

#local RustyIronTexture =
texture {
	bozo
	texture_map {
		[0      RustTexture]
		[0.3    RustTexture] 
		[0.6    IronTexture] 
		[1      IronTexture]
	}
	warp {turbulence 1 omega 0.6 lambda 4}
	scale <0.5,1,0.5>
}

#declare rusted_metal_tex1 =
texture {
        average
        texture_map {
                [1      pigment {
	                	bozo
	                	frequency 2
	                	turbulence 0.4
	                	octaves 8 
                                lambda 1.5 
                                omega 0.8
	                	color_map {
	                		[0      rgb <87*1.2,71,45*0.8>/255]
	                		[0.6    rgb <86*1.2,45,1*0.8>/255]
	                		[1      rgb <50*1.2,21,2*0.8>/255]
	                	}
	                }
	                normal {
                                average
                                normal_map {
                                        [1      granite 
                                                1.4 
                                                turbulence 0.4 
                                                octaves 8 
                                                lambda 1.5 
                                                omega 0.8
                                        ]
                                        [1      pigment_pattern {sponge_pig} 
                                                8 
                                                accuracy 0.001 
                                                cubic_wave
                                                scale 31.25
                                        ]
                                }
                        }
	                finish {
                                ambient 0 
                                diffuse 0.6 
                                specular 0.05 
                                roughness 0.05
                        }
                        scale 0.032
                ]
                [0.1    RustTexture2]
        }
}

#declare rusted_metal_tex2 =
texture {
        average
        texture_map {
                [1      pigment {
	                	bozo
	                	frequency 2
	                	turbulence 0.4
	                	octaves 8 
                                lambda 1.5 
                                omega 0.8
	                	color_map {
	                		[0      rgb <87*1.2,71,45*0.8>/255]
	                		[0.6    rgb <86*1.2,45,1*0.8>/255]
	                		[1      rgb <50*1.2,21,2*0.8>/255]
	                	}
	                }
	                normal {
                                average
                                normal_map {
                                        [1      granite 
                                                1.4 
                                                turbulence 0.4 
                                                octaves 8 
                                                lambda 1.5 
                                                omega 0.8
                                        ]
                                        [1      pigment_pattern {sponge_pig} 
                                                4 
                                                accuracy 0.001 
                                                cubic_wave
                                                scale 12.5
                                        ]
                                }
                        }
	                finish {
                                ambient 0 
                                diffuse 0.6 
                                specular 0.05 
                                roughness 0.05
                        }
                        scale 0.08
                ]
                [0.1    RustTexture2]
        }
}

// David Heys  Rust Texture  http://news.povray.org/povray.text.scene-files/thread/%3C382F438C.1AFD4DBC%40gci.net%3E/?ttop=414558&toff=650
 
#declare Rust2 =
texture {
        pigment {
                bozo
                turbulence 0.9
                color_map {
                        [0      rgbf <0.5, 0.5, 0.7, 1>]
                        [0.22   rgbf <0.6, 0.2, 0.1, 1>]
                        [0.35   rgbf <0.3, 0.0, 0.0, 0.95>]
                        [0.65   rgbf <1, 0.6, 0.0, 0.85>]
                        [0.85   rgbf <0.8, 0.3, 0.0, 0.75>]
                        [0.95   rgbf <0.6, 0.2, 0.0, 0.95>]
                        [1      rgbf <0.4, 0.0, 0.0, 0.55>]
                }
        }
        normal {
                bozo 12.5
                turbulence 0.9
                accuracy 0.003
        }
        finish {
                specular 0.13
                roughness 0.6
      }
        scale 0.2
}
texture {
        pigment {
                bozo
                turbulence 0.9
                color_map {
                        [0      rgbf <0.5, 0.5, 0.7, 0.95>]
                        [0.22   rgbf <0.6, 0.2, 0.1, 0.95>]
                        [0.35   rgbf <0.3, 0.0, 0.0, 0.9>]
                        [0.65   rgbf <1, 0.6, 0.0, 0.8>]
                        [0.85   rgbf <0.8, 0.3, 0.0, 0.7>]
                        [0.95   rgbf <0.6, 0.2, 0.0, 0.9>]
                        [1      rgbf <0.4, 0.0, 0.0, 0.5>]
                }
        }
        normal {
                bozo 12.5
                turbulence 0.9
                accuracy 0.003
        }
        finish {
                specular 0.13
                roughness 0.6
        }
        scale 0.25
}
texture {
        pigment {
                bozo
                turbulence 0.9
                color_map {
                        [0      rgbf <0.5, 0.5, 0.7, 0.9>]
                        [0.22   rgbf <0.6, 0.2, 0.1, 0.9>]
                        [0.35   rgbf <0.3, 0.0, 0.0, 0.85>]
                        [0.65   rgbf <1, 0.6, 0.0, 0.75>]
                        [0.85   rgbf <0.8, 0.3, 0.0, 0.65>]
                        [0.95   rgbf <0.6, 0.2, 0.0, 0.85>]
                        [1      rgbf <0.4, 0.0, 0.0, 0.45>]
                }
        }
        normal {
                bozo 12.5
                turbulence 0.9 
                accuracy 0.003
        }
        finish {
                specular 0.13
                roughness 0.6
        }
        scale 0.3
}
texture {
        pigment {
                bozo
                turbulence 0.9
                color_map {
                        [0      rgbf <0.5, 0.5, 0.7, 0.85>]
                        [0.22   rgbf <0.6, 0.2, 0.1, 0.85>]
                        [0.35   rgbf <0.3, 0.0, 0.0, 0.8>]
                        [0.65   rgbf <1, 0.6, 0.0, 0.7>]
                        [0.85   rgbf <0.8, 0.3, 0.0, 0.6>]
                        [0.95   rgbf <0.6, 0.2, 0.0, 0.8>]
                        [1      rgbf <0.4, 0.0, 0.0, 0.4>]
                }
        }
        normal {
                bozo 12.5
                turbulence 0.9
                accuracy 0.003
        }
        finish {
                specular 0.13
                roughness 0.6
        }
        scale 0.35
}
texture {
        pigment {
                bozo
                turbulence 0.9
                color_map {
                        [0      rgbf <0.5, 0.5, 0.7, 0.8>]
                        [0.22   rgbf <0.6, 0.2, 0.1, 0.8>]
                        [0.35   rgbf <0.3, 0.0, 0.0, 0.75>]
                        [0.65   rgbf <1, 0.6, 0.0, 0.65>]
                        [0.85   rgbf <0.8, 0.3, 0.0, 0.55>]
                        [0.95   rgbf <0.6, 0.2, 0.0, 0.75>]
                        [1      rgbf <0.4, 0.0, 0.0, 0.35>]
                }
        }
        normal {
                bozo 12.5
                turbulence 0.9
                accuracy 0.003
        }
        finish {
                specular 0.13
                roughness 0.6
        }
        scale 0.4
}
texture {
        pigment {
                bozo
                turbulence 0.9
                color_map {
                        [0      rgbf <0.5, 0.5, 0.7, 0.75>]
                        [0.22   rgbf <0.6, 0.2, 0.1, 0.75>]
                        [0.35   rgbf <0.3, 0.0, 0.0, 0.7>]
                        [0.65   rgbf <1, 0.6, 0.0, 0.6>]
                        [0.85   rgbf <0.8, 0.3, 0.0, 0.5>]
                        [0.95   rgbf <0.6, 0.2, 0.0, 0.7>]
                        [1      rgbf <0.4, 0.0, 0.0, 0.3>]
                }
        }
        normal {
                bozo 12.5
                turbulence 0.9
                accuracy 0.003
        }
        finish {
                specular 0.13
                roughness 0.6
        }
        scale 0.45
} 

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
	                [0.68   Rust2 scale 0.4]
	                [0.73   RustTexture scale 0.8] 
	                [0.78   RustyIronTexture scale 0.8]
                }
        }
	interior {ior 1.5}
	scale 1
} 

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
	                [0.6    Rust2 scale 0.4]
	                [0.71   RustTexture scale 0.8] 
	                [0.82   RustyIronTexture scale 0.8]
                }
        }
	interior {ior 1.5}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 18) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

#declare rf = 0.5;

#declare Paint0 =
texture {
	pigment {color srgb <0.09,0.1,0.11>}
        normal {bumps 0.05 scale 0.02}
	finish {
		specular 0.6
                roughness 0.045
                crand 0.002
		ambient 0
                reflection 0.004
	}
}
texture {
        pigment {
                wrinkles
                scale 0.14
                pigment_map {
                        [0.57   color rgbf 1]
                        [0.7    dents scale 0.2
                                color_map {
                                        [0      rgbf 1]
                                        [1      rgbf <0.98,1,0.99,0.5>]
                                }
                        ] 
                        [0.83   color rgbf 1]
                }
        }
        normal {
                wrinkles
                scale 0.14
                normal_map {
                        [0.57   dents 0 scale 0.2]
                        [0.7    dents 1 scale 0.2]
                        [0.83   dents 0 scale 0.2]
                }
        }
        finish {
                ambient 0
                diffuse 0.6
                reflection 0.001
                specular 0.001
                roughness 9
        }
}

#declare Paint1 =
texture {
	pigment {color srgb <0.09,0.1,0.11>}
        normal {bumps 0.05 scale 0.02}
	finish {
		specular 0.6
                roughness 0.045
                crand 0.002
		ambient 0
                reflection 0.004
	}
}

#declare Paint2 =
texture {
	pigment {color srgb <0.09,0.1,0.11>}
	normal {
		average
		normal_map {
			[1      bumps 0.15 scale 0.02]
			[1      bumps 1.2*2 scale 0.1]
			[1      granite 0.45*2 scale 1]
		}
	}
	finish {
		specular 0.6
                roughness 0.045
                crand 0.002
		ambient 0
                reflection 0.004
	}
}

// Nicolas Rougier  Iso-chain  http://news.povray.org/povray.binaries.scene-files/thread/%3C42bbb1a7%40news.povray.org%3E/

#declare p_rust =
pigment {
	image_map {jpeg "rust.jpg"}
	translate -0.5
	scale 10
	warp {turbulence 1 lambda 2}
}

#declare p_brass =
pigment {
	image_map {jpeg "iron06.jpg"}
	translate -0.5
	scale 10
	warp {turbulence 1 lambda 2}
} 

#declare rusted_metal1 = 
texture { 
        pigment {	        
                cells
	        warp {turbulence 1 lambda 3}
	        pigment_map {
		        [0      p_rust]
		        [1      p_brass]
	        }
        }
	normal {
		average
		normal_map {
			[1      granite 0.2 scale 0.1]
                        [1      cells -2 warp {turbulence 1 lambda 3}]
		}
	}
        finish {
                specular 0.25 
                roughness 0.01 
                diffuse 0.5 
                ambient 0
        }
}

#declare rusted_metal2 = 
texture { 
        pigment {	        
                cells
	        warp {turbulence 1 lambda 3}
	        pigment_map {
		        [0      p_rust]
		        [1      p_brass]
	        }
        }
	normal {
		average
		normal_map {
			[1      granite 0.2 scale 0.1]
                        [1      cells -2 warp {turbulence 1 lambda 3}]
		}
	}
        finish {
                specular 0.25 
                roughness 0.01 
                metallic 
                diffuse 0.5 
                ambient 0 
                reflection {0, 1 falloff 5 metallic} 
                conserve_energy
        }
}

#declare rusted_metal3 = 
texture {
        cells
        warp {turbulence 1 lambda 3}
        texture_map {
	        [0      rusted_metal1]
	        [1      rusted_metal2]
        }
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
        texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
	                    [0.71   Paint0 scale 4]
	                    [0.715  Paint1 scale 4]
	                    [0.73   Paint1 scale 4]
	                    [0.76   Paint2 scale 4] 
	                    [0.765  rusted_metal3 scale 0.4]
                }
        }
	    interior {ior 1.5}
	    scale 1
} 

#declare T6_ =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {  
	                    [0.7    Paint0 scale 4]
	                    [0.73   Paint1 scale 4]
	                    [0.745  Paint1 scale 4]
	                    [0.775  Paint2 scale 4] 
	                    [0.78   rusted_metal3 scale 0.4]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 19) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// isowood
 
#macro IW_Warp_02 (Seed, xSize, ySize, zSize)

#local SZ = (xSize+ySize)*0.5*0.1;
#local Density = 0.1;
warp {
        black_hole <xSize*0.5,0,0>, SZ
        falloff 2.5
        strength 2
        repeat <min (xSize, SZ/Density),min (ySize, SZ/Density),SZ/Density>
        turbulence <0.02,0.75,0.75>
        inverse
}
#local SZ = (xSize+ySize)*0.5*0.15;
#local Density = 0.1;
warp {
        black_hole <xSize*0.5,0,0>, SZ
        falloff 2.1
        strength 3.7
        repeat <min (xSize, SZ/Density),min (ySize, 0.7*SZ/Density),0.8*SZ/Density>
        turbulence <0,0.4,0.4>
        inverse
}

#end 

#macro IW_Select_Warp (WarpNbr, Seed, xSize, ySize, zSize)

IW_Warp_02 (Seed, xSize, ySize, zSize)

#end

#macro IW_Plank_Round_CutN (Seed, xSize, ySize, zSize, Rotate, Translate, Round, Strength, Strength2, Pigm, Fin, C_Map, WarpNbr, fn_Max_Val)

#local rd = seed (Seed);

#local fn_Max = fn_Max_Val+<0,0,0>;

#local Trsx = (rand (rd)-0.5)*Translate*xSize;
#local Trsy = (rand (rd)-0.5)*Translate*ySize;
#local Trsz = (rand (rd)-0.5)*Translate*zSize;
#local Rotx = (rand (rd)-0.5)*Rotate;
#local Roty = (rand (rd)-0.5)*Rotate;

#local fn_Wood =
function {
        pigment {
                Pigm
                color_map {
                        [0      rgb 0]
                        [1      rgb 1]
                }
                translate <Trsx,Trsy,Trsz>
                rotate Rotx*x
                rotate Roty*y
                IW_Select_Warp (WarpNbr, Seed, xSize, ySize, zSize)
        }
}

#local fn_Disp =
function {
        pigment {
                average
                pigment_map {
                        [1      function {f_noise3d (0,0,z*1.6)*0.3} 
                                color_map {
                                        [0      rgb 0]
                                        [1      rgb x]
                                }
                        ]
                        [1      function {f_noise3d (0,0,-z*1.6)*0.3}
                                color_map {
                                        [0      rgb 0]
                                        [1      rgb y]
                                }
                        ]
                }
        }
}
#local fnShape  = function {f_rounded_box (x,y,z, Round, xSize*0.5, ySize*0.5, zSize*0.5+Round)}
#local fnShape2 = function {(abs (z)-zSize*0.5)}

#local fnShapeT  = function {fnShape (x+fn_Disp (x,y,z).x, y+fn_Disp (x,y,z).y,z+fn_Disp (x,y,z).z)}
#local fnShape2T = function {fnShape2(x+fn_Disp (x,y,z).x, y+fn_Disp (x,y,z).y,z+fn_Disp (x,y,z).z)}
#declare fnBumpsT  = function {fn_Wood (x+fn_Disp (x,y,z).x, y+fn_Disp (x,y,z).y,z+fn_Disp (x,y,z).z).grey}

#end

#declare P_IW_10 =
pigment {
        wood
        octaves 6
        lambda 2.5
        turbulence <0.06,0.06,0.75>
        scale      <0.02,0.02,0.3>
}

#declare Fin_W_02 =
finish {
        ambient 0.1*0
        diffuse 0.95
        brilliance 1.4
        specular 0.4
        roughness 0.02
}

#declare Fin_W_02d =
finish {
        ambient 0.1*0
        diffuse 0.55
        brilliance 1.4
}

#declare GammaFact = 1;
#declare ColorDiff = <0,0,0>; 

#macro ColorCorrect (Color, Gamma, ColDiff)

rgb <pow (Color.red+ColDiff.red,Gamma),pow (Color.green+ColDiff.green,Gamma),pow (Color.blue+ColDiff.blue,Gamma)> 

#end

#declare CM_IW_02 =
color_map {
        [0      ColorCorrect (<0.949,0.792,0.514>, GammaFact, ColorDiff)]
        [0.3    ColorCorrect (<0.855,0.651,0.376>, GammaFact, ColorDiff)]
        [0.6    ColorCorrect (<0.831,0.596,0.275>, GammaFact, ColorDiff)]
        [0.9    ColorCorrect (<0.620,0.447,0.204>, GammaFact, ColorDiff)]
}

#declare CM_IW_02d =
color_map {
        [0      ColorCorrect (<0.949,0.792+0.15,0.514+0.35>, GammaFact, ColorDiff)]
        [0.3    ColorCorrect (<0.855,0.651+0.15,0.376+0.35>, GammaFact, ColorDiff)]
        [0.6    ColorCorrect (<0.831,0.596+0.15,0.275+0.35>, GammaFact, ColorDiff)]
        [0.9    ColorCorrect (<0.620,0.447+0.15,0.204+0.35>, GammaFact, ColorDiff)]
}

IW_Plank_Round_CutN  (17, 0.3, 1.6, 8, 2, 0, 0.018, 0.0035, 0.005, pigment {P_IW_10 scale 1.6} , Fin_W_02, CM_IW_02, 2, 0.3)

#local T_WoodA = 
texture {
        pigment {
                function {fnBumpsT (x,y,z)}
                color_map {CM_IW_02}
        }
        normal {function {fnBumpsT (x,y,z)}, -0.1 accuracy 0.004}
        finish {Fin_W_02}
}

#declare Twb =
texture {
        T_WoodA
        rotate -90*y
        rotate 90*z
        translate <3.3,3.8,0.9>*5
} 

#local T_WoodAd = 
texture {
        pigment {
                function {fnBumpsT (x,y,z)}
                color_map {CM_IW_02d}
        }
        normal {function {fnBumpsT (x,y,z)}, -0.5 accuracy 0.004}
        finish {Fin_W_02d}
}

#declare Twd =
texture {
        T_WoodAd
        rotate -90*y
        rotate 90*z
        translate <3.3,3.8,0.9>*5
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
        texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
	                [0.7    Twd scale 20]
	                [0.9    Twb scale 20]
                }
        }
	interior {ior 1.4}
	scale 1
} 

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {  
	                [0.7    Twd scale 20]
	                [0.86   Twb scale 20]
                }
        }
	interior {ior 1.4}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 20) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// poolballs.pov

#declare f_ivory0 =
finish {
        phong 1 
        phong_size 200
        reflection {0, 1 fresnel}  
        conserve_energy
}

#declare f_ivory1 =
finish {
        phong 0.7 
        phong_size 100
        reflection {0, 0.5 fresnel}  
        conserve_energy
}

#declare f_ivoryd =
finish {
        phong 0.3 
        phong_size 50
        reflection {0, 0.25 fresnel}  
        conserve_energy
}

#declare n_ivory =
normal {
        average
        normal_map {
                [1      wrinkles 0.1 scale 0.02]
                [1      wrinkles 0.1 scale 0.063]
                [1      wrinkles 0.1 scale 0.2]
        }
}

#declare n_ivory1 =
normal {
        average
        normal_map {
                [1      wrinkles 0.2 scale 0.02]
                [1      wrinkles 0.2 scale 0.063]
                [1      wrinkles 0.2 scale 0.2]
        }
}

#declare n_ivoryd =
normal {
        average
        normal_map {
                [1      wrinkles 0.6 scale 0.02]
                [1      wrinkles 0.6 scale 0.063]
                [1      wrinkles 0.6 scale 0.2]
        }
}

#declare mfa = 0.33;

#declare p_dirt1 =
pigment {
        average
        pigment_map {
                [1      wrinkles 
                        scale 0.02 
                        color_map {
                                [0      srgb <242,231,211>/242 filter mfa]
                                [1      srgb <0.471,0.093,0.043>*<242,231,211>/242]
                        }
                ]
                [1      wrinkles 
                        scale 0.063 
                        color_map {
                                [0      srgb <242,231,211>/242 filter mfa]
                                [1      srgb <0.471,0.093,0.043>*<242,231,211>/242]
                        }
                ]
                [1      wrinkles 
                        scale 0.2 
                        color_map {
                                [0      srgb <242,231,211>/242 filter mfa]
                                [1      srgb <0.471,0.093,0.043>*<242,231,211>/242]
                        }
                ]
        }
}

#declare p_dirt =
pigment {
        average
        pigment_map {
                [1      wrinkles 
                        scale 0.02 
                        color_map {
                                [0      srgb <242,231,211>/242 filter mfa]
                                [0.5    srgb <0.471,0.093,0.043>*<242,231,211>/242]
                        }
                ]
                [1      wrinkles 
                        scale 0.063 
                        color_map {
                                [0      srgb <242,231,211>/242 filter mfa]
                                [0.5    srgb <0.471,0.093,0.043>*<242,231,211>/242]
                        }
                ]
                [1      wrinkles 
                        scale 0.2 
                        color_map {
                                [0      srgb <242,231,211>/242 filter mfa]
                                [0.5    srgb <0.471,0.093,0.043>*<242,231,211>/242]
                        }
                ]
        }
}

#declare dirt_level = 0.33;

#declare mfa = 0.33;

#declare t_ivory0 =
texture {
        pigment {color srgb <242,231,211>/242 filter mfa}
        normal {n_ivory} 
        finish {f_ivory0}
}
 
#declare t_ivory1 =
texture {
        pigment {p_dirt1}
        normal {n_ivory1} 
        finish {f_ivory1}
}

#declare t_ivoryd =
texture {
        pigment {p_dirt}
        normal {n_ivoryd} 
        finish {f_ivoryd}
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
        texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
	                [0.64   t_ivoryd scale 4]
	                [0.68   t_ivory1 scale 4]
	                [0.7    t_ivory1 scale 4]
	                [0.74   t_ivory0 scale 4]
                }
        }
	interior {
                media {
                        scattering {1, 1}
                        absorption 1
                }
                ior 1.54
        }
	scale 1
} 

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {  
	                [0.6    t_ivoryd scale 4]
	                [0.64   t_ivory1 scale 4]
	                [0.67   t_ivory1 scale 4]
	                [0.73   t_ivory0 scale 4]
                }
        }
	interior {
                media {
                        scattering {1, 1}
                        absorption 1
                }
                ior 1.54
        }
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 21) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Robert W. McGregor  Random Rectangular Mazes  http://news.povray.org/povray.binaries.scene-files/thread/%3Cweb.4f3838b562b6f9ae94d713cc0@news.povray.org%3E/

#declare Tm =
texture {T_Grnt27  scale <0.7,0.99,0.7> rotate <0,0,40> scale 0.75}
texture {T_Grnt20a scale <1.9,3,0.5> rotate <0,0,-50> scale 0.75}
texture {T_Grnt12a scale <1,1.3,2> rotate <0,0,40> scale 0.75}
texture {T_Crack1  scale <1,0.6,1> rotate <10,0,-20> scale 0.75}
texture {
	pigment {color rgbt 1 filter 0.15}
	normal {
		average
		normal_map {
			[1      granite 3 scale 5]
			[1      granite 2 scale 2]
			[0.5    granite 3 scale 0.35]
			[0.5    granite 5 scale 0.15]
			[0.35   granite 10 scale 0.05]
		}
		scale 0.35
	}
	finish {
		specular 0.2
		roughness 0.05
		reflection {0, 0.25 fresnel on}
		conserve_energy
	}
}

#declare old_pitted_steel_texture =
texture {
	pigment {
		granite scale 0.5 // AGATE works well for this too.
		color_map {
			[0     rgb vpow (0.8*<0.4,0.4,0.38>, 0.7)*1.2]
			[0.153 rgb vpow (<0.4,0.4,0.4>, 0.7)*1.2*1.2]
			[0.398 rgb vpow (0.5*<0.4,0.4,0.35>, 0.7)*1.2]
			[0.398 rgb vpow (0.2*<0.7,0.7,0.7>, 0.7)*1.2]
			[1     rgb vpow (<0.405,0.380,0.345>, 0.7)*1.2]
		}
	}
	normal {granite 0.7 scale 1}
	finish {diffuse 0.9}
	scale 0.02
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.62   old_pitted_steel_texture scale 1]
                        [0.8    Tm scale 8]
                }
        }
	interior {ior 2}
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.57   old_pitted_steel_texture scale 1]
                        [0.77   Tm scale 8]
                }
        }
	interior {ior 2}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 22) #declare light_ = 0.4; /////////////////////////////////////////////////////////////////////////////////////

// Tekno Frannansa  1volcano  http://www.irtc.org/ftp/pub/stills/2006-02-28/1volcano.zip

#declare Th =
texture {
	pigment_pattern {
		pigment_pattern {
			slope {y, 0.5, 1}
			pigment_map {
				[0      //vertical - tortured cracks - similar to the pillow lava
					crackle 
                                        scale 8
					turbulence 0.3 
                                        lambda 4 
                                        omega 0.5
					#local turb_scale = 0.7;
					scale 1/turb_scale 
                                        warp {turbulence 2 octaves 3} 
                                        scale turb_scale
				]
				[1      rgb 1] //horizontal
			}
		}
		color_map {
			[0      rgb 0]
			[1      rgb 1]
		}
	}
	cubic_wave
	texture_map {
		[0      //molten lava
			pigment {color rgb <5,0.5,0.05>}
			finish {emission 1}
		]
		[1.005  //solidified crust
			pigment {
                                granite 
                                color_map {
                                        [0      rgb 0.1]
                                        [1      rgb 0.07]
                                }
                        }
			finish {diffuse 1.5 brilliance 2}
			normal {
				pigment_pattern {
					granite
					warp {turbulence 2 octaves 3}
					color_map {
                                                [0      rgb 0]
                                                [1      rgb 1]
                                        }
				} 
                                1
			}
                        scale 12
		]
	}
}

#declare Tm =
texture {
	pigment_pattern {
		pigment_pattern {
			slope {y, 0.5, 1}
			pigment_map {
				[0      //vertical - tortured cracks - similar to the pillow lava
					crackle 
                                        scale 8
					turbulence 0.3 
                                        lambda 4 
                                        omega 0.5
					#local turb_scale = 0.7;
					scale 1/turb_scale 
                                        warp {turbulence 2 octaves 3} 
                                        scale turb_scale
				]
				[1      rgb 1] //horizontal
			}
		}
		color_map {
			[0      rgb 0]
			[1      rgb 1]
		}
	}
	cubic_wave
	texture_map {
		[0      //molten lava
			pigment {color rgb <5,0.5,0.05>}
			finish {emission 0.5}
		]
		[1.005  //solidified crust
			pigment_pattern {
				granite
				warp {turbulence 2 octaves 3}
				color_map {
                                        [0      rgb 0]
                                        [1      rgb 1]
                                }
	                }
                        texture_map {
                                [0      pigment {color rgb <5,0.5,0.05>}
			                finish {emission 0.25}
                                ]
                                [0.5    pigment {
                                                granite 
                                                color_map {
                                                        [0      rgb 0.1]
                                                        [1      rgb 0.07]
                                                }
                                        }
			                finish {diffuse 1.5 brilliance 2}
			                normal {
			                	pigment_pattern {
			                		granite
			                		warp {turbulence 2 octaves 3}
			                		color_map {
                                                                [0      rgb 0]
                                                                [1      rgb 1]
                                                        }
			                	} 
                                                1
			                }
                                        scale 12
                                ]
                        }
		]
	}
}

#declare Tc =
texture {
        pigment {
                granite 
                color_map {
                        [0      rgb 0.1]
                        [1      rgb 0.07]
                }
        }
        finish {diffuse 1.5 brilliance 2}
        normal {
        	pigment_pattern {
        		granite
        		warp {turbulence 2 octaves 3}
        		color_map {
                                [0      rgb 0]
                                [1      rgb 1]
                        }
        	} 
                1
        }
        scale 12
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.45   Th scale 1]
                        [0.61   Tm scale 1]
                        [0.77   Tc scale 1]
                }
        }
	interior {ior 1.5}
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.47   Th scale 1]
                        [0.62   Tm scale 1]
                        [0.77   Tc scale 1]
                }
        }
	interior {ior 1.5}
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 23) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// H.E. Day  Patina and metal wear test v.5  http://news.povray.org/povray.binaries.images/message/%3C3A998895.8C45A04F%40heday.freeservers.com%3E/#%3C3A998895.8C45A04F%40heday.freeservers.com%3E

#declare Base_Tex2 =
texture {
	pigment {color srgb 1}
	finish {ambient 0 diffuse 1*0.625 phong 0.75 metallic}
}

#declare Scratching =
texture {
	pigment {
		bozo
		color_map {
			[0.2    srgb 1.25]
			[0.25   srgbt 1]
		}
		scale <20,20,1>
		scale 0.1
		rotate 71657
	}
	finish {ambient 0 diffuse 1*0.6 phong 0.25 metallic}
}

#declare Scortching =
texture {
	pigment {
		bozo
		color_map {
			[0.275  srgbt <0,0,0,0.75>]
			[0.375  srgbt <0,0,0,0.625>]
			[1      srgbt <0,0,0,1>]
		}
		scale <1,1,5>
		warp {turbulence 0.5}
		scale 1/3
	}
	finish {ambient 0 diffuse 1*0.6 phong 0.25 metallic 0.5}
}

#declare Base_Tex1 =
texture {
	pigment {color srgb 0.5}
	finish {ambient 0 diffuse 1*0.6 phong 0.75*0.5 metallic}
}
texture {Scratching scale 0.05}
texture {Scratching rotate -56767 scale 0.05}
texture {Scratching rotate 8967 scale 0.05}
texture {Scortching scale <1,1,2>*0.05}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.76   Base_Tex1 scale 20]
                        [0.76   Base_Tex2 scale 20]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	    [0.79   Base_Tex1 scale 20]
                        [0.79   Base_Tex2 scale 20]
                }
        }
	    interior {ior 1.5}
	    scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 24) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// Jim Charter  more leather grain tests  http://news.povray.org/povray.binaries.images/message/%3C425aeefa%40news.povray.org%3E/#%3C425aeefa%40news.povray.org%3E

#declare Leather1 =
texture {    
            pigment {color rgb <10,10,28>/255}
            finish { 
                    diffuse 1
                    specular 0.75
                    roughness 0.035
                    ambient 0
                    reflection {
                            0.075, 0.15
                            fresnel 1
                            metallic 0
                    }
            }
            normal {
                    average
                    normal_map {
                            [1      pigment_pattern {
                                            crackle
                                        scale 0.04
                                        poly_wave 0.045
                                        pigment_map {
                             	                [0      rgb 0]
                             	                [1      rgb 0.7]
                                        }
                                    }
                                    0.5
                            ]
                            [1	dents -1
                            	slope_map {
                            		[0	<1,0>]
                            		[0.6	<1,0>]
                            		[0.6	<1,-1>]
                            		[1	<0,0>]
                            	}
                                    scale 0.1
                            ]
                    }
	    }
        scale 0.7
}

// Marc Jacquier  Leather  http://news.povray.org/povray.binaries.images/message/%3C3e46d31a%241%40news.povray.org%3E/#%3C3e46d31a%241%40news.povray.org%3E

#declare Leather2 =
texture {
	pigment {//rgb <0.65,0.4,0.3>}
		average
		pigment_map {
			[1      crackle
				metric 0.3
				turbulence 0.1
				color_map {
					[0.95   rgb <0.55,0.45,0.4>]
					[1      rgb <0.55,0.45,0.4>*2]
				}
			]
			[1      crackle
				metric 0.3
				turbulence 0.1
				scale 0.3
				color_map {
					[0.95   rgb <0.55,0.45,0.4>]
					[1      rgb <0.55,0.45,0.4>*2]
				}
			]
			[1      dents
				scale 0.01
				color_map {
					[0.95   rgb <0.55,0.45,0.4>]
					[1      rgb <0.55,0.45,0.4>*-1]
				}
			]
		}
		scale  0.14
	}
	normal {
		average
		normal_map {
			[1      crackle
				metric 0.5
				turbulence 0.1
                                accuracy 0.001
			]
			[1      crackle
				metric 0.5
				turbulence 0.1
				scale 0.3
                                accuracy 0.001
			]
			[1      dents -1.7
				scale 0.01
                                accuracy 0.001
			]
			[1      bumps 0.3*5
				warp {turbulence 1}
				scale 2
			]
			[1      bumps 0.2*5
				scale 0.01
			]
		}
		scale  0.14
	}
	finish {
		ambient 0
		specular 0.4
		roughness 0.02
	}
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.78   Leather1 scale 12]
                        [0.78   Leather2 scale 3]
                }
        }
        interior { 
                ior 1.4 
                fade_distance 0.5
                fade_power 1001
        }
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.79   Leather1 scale 12]
                        [0.79   Leather2 scale 3]
                }
        }
        interior { 
                ior 1.4 
                fade_distance 0.5
                fade_power 1001
        }
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

#if (mat = 25) #declare light_ = 1; /////////////////////////////////////////////////////////////////////////////////////

// attempt to simulate "3D fabric"

#declare streaks = 
pigment {
        bozo 
        color_map {
                [0.36   rgb 0] 
                [0.98   rgb 1]
        } 
        scale <30,0.3,0.3>
}

#declare streaksd = 
pigment {
        bozo 
        color_map {
                [0.36   rgb <9,31,146>/255] 
                [0.98   rgb <214,236,255>/255]
        } 
        scale <30,0.3,0.3>
}

#declare streaksb = 
pigment {
        bozo 
        color_map {
                [0.36   rgb <136,184,253>/255] 
                [0.98   rgb 1]
        } 
        scale <30,0.3,0.3>
}

#declare f_fabric =
function {
	pigment {
		wrinkles
		turbulence 0.3
		lambda 3
		pigment_map {
		        [0      streaks]
		        [0.333  streaks rotate 90*y translate -10]
		        [0.667  streaks rotate 90*x translate 10]
		}
	}
}

#declare n_jeans =
normal {
	average
	normal_map {
	        [1      function {f_fabric (x,y,z).x} -2 accuracy 0.002]
	        [1      bumps 0.1 scale 0.01]
	}
}

#declare jeansd =
texture {
	pigment {
		wrinkles
		turbulence 0.3
		lambda 3
		pigment_map {
		        [0      streaksd]
		        [0.333  streaksd rotate 90*y translate -10]
		        [0.667  streaksd rotate 90*x translate 10]
		}
	}
	normal {n_jeans}
	finish {brilliance 1 diffuse 0.6}
        rotate z*90       
}

#declare jeansb =
texture {
	pigment {
		wrinkles
		turbulence 0.3
		lambda 3
		pigment_map {
		        [0      streaksb]
		        [0.333  streaksb rotate 90*y translate -10]
		        [0.667  streaksb rotate 90*x translate 10]
		}
	}
	normal {n_jeans}
	finish {brilliance 0.7 diffuse 0.6}
        rotate z*90       
}

//__________________________________________________________________________________________________________________________

#declare T6 =
material {
	    texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.75   jeansd scale 0.2 rotate y*135]
                        [0.83   jeansb scale 0.2 rotate y*135]
                }
        }
        interior { 
                ior 1.4 
                fade_distance 0.5
                fade_power 1001
        }
	scale 1
}

#declare T6_ =
material {
	texture {
                pigment_pattern {
                        illusion_raw
                        matrix <
                                illusion_x.x,illusion_x.y,illusion_x.z,
                                illusion_y.x,illusion_y.y,illusion_y.z,
                                illusion_z.x,illusion_z.y,illusion_z.z,
                                illusion_t.x,illusion_t.y,illusion_t.z
                        >
                }
                texture_map {
                	[0.75   jeansd scale 0.2 rotate y*210]
                        [0.87   jeansb scale 0.2 rotate y*210]
                }
        }
        interior { 
                ior 1.4 
                fade_distance 0.5
                fade_power 1001
        }
	scale 1
}

#end /////////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   

#declare lights = <50000,80000,-50000>;
light_source {
        lights,
        color rgb <2.42,2.23,1.87>*0.4*light_
        //area_light <9000,0,0>, <0,9000,0> 5,5 adaptive 1 jitter circular orient
}

sphere {
        0, 120000
        hollow
        pigment {   
                image_map {
                        hdr "kitchen_probe2.hdr"
                        gamma 2.2
                        //gamma 1
                        map_type 1
                        interpolate 2
                }
                rotate y*-20 
        }
        finish {diffuse 0 emission 0.8*light_}
}
 
#include "chinese_coin_POV_geom.inc"
#include "golden_column_POV_geom.inc"
#include "man_bust_POV_geom.inc" 

object {
        chinese_coin_
        translate <0,14.5865001678467,0>
        scale 88/29.3090629577637*<-1,1,1> 
        rotate y*135
        translate <-41,-40,0>
        material {T6}
} 
object {
        golden_column_
        translate <-10.4126052856445+20,-176,-9.0140266418457+20>
        scale 18/966.555877685547*7.5 
        rotate y*260
        translate <43,-40,0> 
        material {T6_}
}
object {
        man_bust_
        translate <-21.19413,266.5959,75.80349>
        scale 45/465.3022*<-1,1,1> 
        rotate y*210
        translate <43,0,0>
        material {T6_}
}                                                  

                                                                                                                                                                                                                                                                                                                                                                                                    